Czech Core Metadata Model

This file documents Czech Core Metadata Model.

## Overview

View for Czech Core Metadata Model

## Class profiles

#### Access rights

Profiled class IRI(s) | dcterms:RightsStatement
IRI | https://model.ccmm.cz/research-data/AccessRights
Label | Access rights
Definition | A statement about the access rights to the dataset.
Profiles | class profile Rights Statement (https://mff-uk.github.io/specifications/dcat-ap#RightsStatement) class profile Rights Statement (https://mff-uk.github.io/specifications/dcat-dap#RightsStatement) class Rights Statement (dcterms:RightsStatement) Definition: A statement about the intellectual property rights (IPR) held in or over a resource, a legal document giving official permission to do something with a resource, or a statement about access rights.
Usage note | Use IRI identifier from the register http://purl.org/coar/access_right/.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/AccessRights.label
Label | label
Definition | Label of the access rights vocabulary value.
Domain | Access rights
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.
Usage note | Short label of the value from register http://purl.org/coar/access_right/. Allowed English values are 'embargoes access', 'metadata only access', 'open access' and 'restricted access'.

#### Address

Profiled class IRI(s) | locn:Address
IRI | https://model.ccmm.cz/research-data/Address
Label | Address
Definition | A spatial object that in a human-readable way identifies a fixed location.
Profiles | class Address (locn:Address) Definition:
Usage note | Address shall refer to the IRI identifier of an address from existing Address registry (e.g. RÚIAN for Czechia). In cases, where address identifier does not exist or cannot be used, fill address details using class attributes.

Backwards associations

- from domain →

#### address area

Profiled relationship IRI(s) | locn:addressArea
IRI | https://model.ccmm.cz/research-data/Address.addressArea
Label | address area
Definition | The name of a geographic area that groups Addresses.
Domain | Address
Range | xsd:string [0..*]
Profiles | property address area (locn:addressArea) Definition:
Usage note | This would typically be part of a city, a neighbourhood or village, e.g. Montmartre. Address area is not an administrative unit.

#### administrative unit level 1

Profiled relationship IRI(s) | locn:adminUnitL1
IRI | https://model.ccmm.cz/research-data/Address.administrativeUnitLevel1
Label | administrative unit level 1
Definition | The name of the uppermost level of the address, almost always a country.
Domain | Address
Range | xsd:string [0..*]
Profiles | property admin unit level 1 (locn:adminUnitL1) Definition:
Usage note | Best practice is to use the ISO 3166-1 code but if this is inappropriate for the context, country names should be provided in a consistent manner to reduce ambiguity. For example, either write 'France' or 'FRA' consistently throughout the dataset and avoid mixing the two. The Country controlled vocabulary from the Publications Office can be reused for this.

#### administrative unit level 2

Profiled relationship IRI(s) | locn:adminUnitL2
IRI | https://model.ccmm.cz/research-data/Address.administrativeUnitLevel2
Label | administrative unit level 2
Definition | The name of a secondary level/region of the address, usually a county, state or other such area that typically encompasses several localities.
Domain | Address
Range | xsd:string [0..*]
Profiles | property admin unit level 2 (locn:adminUnitL2) Definition:
Usage note | Values could be a region or province, more granular than level 1.

#### full address

Profiled relationship IRI(s) | locn:fullAddress
IRI | https://model.ccmm.cz/research-data/Address.fullAddress
Label | full address
Definition | The complete address written as a string.
Domain | Address
Range | xsd:string [0..*]
Profiles | property full address (locn:fullAddress) Definition:
Usage note | Use of this property is recommended as it will not suffer any misunderstandings that might arise through the breaking up of an address into its component parts. This property is analogous to vCard's label property but with two important differences: (1) formatting is not assumed so that, unlike vCard label, it may not be suitable to print this on an address label, (2) vCard's label property has a domain of vCard Address; the fullAddress property has no such restriction. An example of a full address is "Champ de Mars, 5 Avenue Anatole France, 75007 Paris, France".

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/Address.label
Label | label
Definition | Address label
Domain | Address [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### locator designator

Profiled relationship IRI(s) | locn:locatorDesignator
IRI | https://model.ccmm.cz/research-data/Address.locatorDesignator
Label | locator designator
Definition | A number or sequence of characters that uniquely identifies the locator within the relevant scope.
Domain | Address
Range | xsd:string [0..*]
Profiles | property locator designator (locn:locatorDesignator) Definition:
Usage note | In simpler terms, this is the building number, apartment number, etc. For an address such as "Flat 3, 17 Bridge Street", the locator is "flat 3, 17".

#### locator name

Profiled relationship IRI(s) | locn:locatorName
IRI | https://model.ccmm.cz/research-data/Address.locatorName
Label | locator name
Definition | Proper noun(s) applied to the real world entity identified by the locator. The locator name could be the name of the property or complex, of the building or part of the building, or it could be the name of a room inside a building.
Domain | Address
Range | xsd:string [0..*]
Profiles | property locator name (locn:locatorName) Definition:
Usage note | The locator name could be the name of the property or complex, of the building or part of the building, or it could be the name of a room inside a building. The key difference between a locator designator and a locator name is that the latter is a proper name and is unlikely to include digits. For example, "Shumann, Berlaymont" is a meeting room within the European Commission headquarters for which locator name is more appropriate than locator.

#### post code

Profiled relationship IRI(s) | locn:postCode
IRI | https://model.ccmm.cz/research-data/Address.postCode
Label | post code
Definition | The code created and maintained for postal purposes to identify a subdivision of addresses and postal delivery points.
Domain | Address
Range | xsd:string [0..*]
Profiles | property post code (locn:postCode) Definition:
Usage note | Post codes are common elements in many countries' postal address systems. One of the many post codes of Paris is for example "75000".

#### post name

Profiled relationship IRI(s) | locn:postName
IRI | https://model.ccmm.cz/research-data/Address.postName
Label | post name
Definition | A name created and maintained for postal purposes to identify a subdivision of addresses and postal delivery points.
Domain | Address
Range | xsd:string [0..*]
Profiles | property post name (locn:postName) Definition:
Usage note | Usually a city, for example "Paris". Eventually name of the post itself.

#### post office box

Profiled relationship IRI(s) | locn:poBox
IRI | https://model.ccmm.cz/research-data/Address.poBox
Label | post office box
Definition | A location designator for a postal delivery point at a post office, usually a number.
Domain | Address
Range | xsd:string [0..*]
Profiles | property PO box (locn:poBox) Definition:

#### thoroughfare

Profiled relationship IRI(s) | locn:thoroughfare
IRI | https://model.ccmm.cz/research-data/Address.thoroughfare
Label | thoroughfare
Definition | The name of a passage or way through from one location to another.
Domain | Address
Range | xsd:string [0..*]
Profiles | property thoroughfare (locn:thoroughfare) Definition:
Usage note | A thoroughfare is usually a street, but it might be a waterway or some other feature. For example, "Avenue des Champs-Élysées".

#### Agent

Profiled class IRI(s) | foaf:Agent
IRI | https://model.ccmm.cz/research-data/Agent
Label | Agent
Definition | Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.
Profiles | class profile Agent (https://mff-uk.github.io/specifications/dcat-ap#Agent) Definition: Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources. class profile Agent (https://mff-uk.github.io/specifications/dcat-dap#Agent) class Agent (foaf:Agent) Definition: An agent (eg. person, group, software or physical artifact).

Backwards associations

- from domain →
- from domain →
- from domain →

#### has contact point

Profiled relationship IRI(s) | dcat:contactPoint
IRI | https://model.ccmm.cz/research-data/Agent.contactPoint
Label | has contact point
Definition | Relevant contact information for the catalogued resource.
Domain | Agent
Range | Contact details [0..*]
Profiles | property contact point (dcat:contactPoint) Definition: Relevant contact information for the catalogued resource. Use of vCard is recommended.

#### has identifier

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier
IRI | https://model.ccmm.cz/research-data/Agent.hasIdentifier
Label | has identifier
Definition | has identifier
Domain | Agent
Range | Identifier [0..*]
Profiles | property has identifier (https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier) Definition: has identifier

#### name

Profiled relationship IRI(s) | foaf:name
IRI | https://model.ccmm.cz/research-data/Agent.name
Label | name
Definition | Name of the agent.
Domain | Agent
Range | xsd:string [1..1]
Profiles | property name (foaf:name) Definition: A name for some thing.
Usage note | It is used for the official name of the agent. For Persons it is combination of first and family names. Recommended format is "family names, first names".

#### Alternate title

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#AlternateTitle
IRI | https://model.ccmm.cz/research-data/AlternateTitle
Label | Alternate title
Definition | Alternate title of the resource.
Profiles | class Alternate title (https://model.ccmm.cz/vocabulary/ccmm#AlternateTitle) Definition: Alternate title of the resource.

Backwards associations

- from domain →

#### has alternate title type

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasType
IRI | https://model.ccmm.cz/research-data/AlternateTitle.hasType
Label | has alternate title type
Definition | Type of the alternate name relation.
Domain | Alternate title
Range | Alternate title type [0..1]
Profiles | property has type (https://model.ccmm.cz/vocabulary/ccmm#hasType) Definition: Reference to the codelist value giving the specific type to the attribute.
Usage note | References to the value from https://vocabs.ccmm.cz/registry/codelist/AlternateTitle/.

#### title

Profiled relationship IRI(s) | dcterms:title
IRI | https://model.ccmm.cz/research-data/AlternateTitle.title
Label | title
Definition | A human-readable name for the subject.
Domain | Alternate title [0..*]
Range | rdf:langString [1..*]
Profiles | property Title (dcterms:title) Definition: A name given to the resource.

#### Alternate title type

Profiled class IRI(s) | skos:Concept
IRI | https://model.ccmm.cz/research-data/AlternateTitleType
Label | Alternate title type
Definition | Type of alternate title.
Profiles | class Concept (skos:Concept) Definition: An idea or notion; a unit of thought.
Usage note | Use value from codelist https://vocabs.ccmm.cz/registry/codelist/AlternateTitle/.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/AlternateTitleType.label
Label | label
Definition | Alternate title type label.
Domain | Alternate title type
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.
Usage note | Use label of a respective value from https://vocabs.ccmm.cz/registry/codelist/AlternateTitle/.

#### Application profile

Profiled class IRI(s) | dcterms:Standard
IRI | https://model.ccmm.cz/research-data/ApplicationProfile
Label | Application profile
Definition | A standard or other specification to which a metadata record conforms.
Profiles | class profile Standard (https://mff-uk.github.io/specifications/dcat-ap#Standard) Definition: A standard or other specification to which a resource conforms. class profile Standard (https://mff-uk.github.io/specifications/dcat-dap#Standard) class Standard (dcterms:Standard) Definition: A reference point against which other things can be evaluated or compared.

Backwards associations

- from domain →
- from domain →
- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/ApplicationProfile.label
Label | label
Definition | Label of application profile
Domain | Application profile [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Checksum

Profiled class IRI(s) | spdx:Checksum
IRI | https://model.ccmm.cz/research-data/Checksum
Label | Checksum
Definition | A value that allows the contents of a file to be authenticated.
Profiles | class profile Checksum (https://mff-uk.github.io/specifications/dcat-ap#Checksum) Definition: A value that allows the contents of a file to be authenticated. class profile Checksum (https://mff-uk.github.io/specifications/dcat-dap#Checksum) class without assigned name (spdx:Checksum) Definition: A Checksum is value that allows the contents of a file to be authenticated. Even small changes to the content of the file will change its checksum. This class allows the results of a variety of checksum and cryptographic message digest algorithms to be represented.
Usage note | This class allows the results of a variety of checksum and cryptographic message digest algorithms to be represented.

Backwards associations

- from domain →

#### checksum value

Profiled relationship IRI(s) | spdx:checksumValue
IRI | https://model.ccmm.cz/research-data/Checksum.checksumValue
Label | checksum value
Definition | A lower case hexadecimal encoded digest value produced using a specific algorithm.
Domain | Checksum [0..*]
Range | xsd:hexBinary [1..1]
Profiles | property profile checksum value (https://mff-uk.github.io/specifications/dcat-ap#Checksum.checksumValue) Definition: A lower case hexadecimal encoded digest value produced using a specific algorithm. property profile checksum value (https://mff-uk.github.io/specifications/dcat-dap#Checksum.checksumValue) property without assigned name (spdx:checksumValue) Definition: The checksumValue property provides a lower case hexidecimal encoded digest value produced using a specific algorithm.
Usage note | Value is generated automatically using given algorithm.

#### uses algorithm

Profiled relationship IRI(s) | spdx:algorithm
IRI | https://model.ccmm.cz/research-data/Checksum.usesAlgorithm
Label | uses algorithm
Definition | The algorithm used to produce the subject Checksum.
Domain | Checksum
Range | Checksum algorithm [1..1]
Profiles | property profile algorithm (https://mff-uk.github.io/specifications/dcat-ap#Checksum.algorithm) Definition: The algorithm used to produce the subject Checksum. property profile algorithm (https://mff-uk.github.io/specifications/dcat-dap#Checksum.algorithm) Definition: Identifies the algorithm used to produce the subject Checksum [SPDX]. property without assigned name (spdx:algorithm) Definition: Identifies the algorithm used to produce the subject Checksum. Currently, SHA-1 is the only supported algorithm. It is anticipated that other algorithms will be supported at a later time.
Usage note | Version 2.2 of [SPDX] defines individuals for the following algorithms: MD2, MD4, MD5, MD6, SHA-1, SHA-224, SHA-256, SHA-384, SHA-512.

#### Checksum algorithm

Profiled class IRI(s) | spdx:ChecksumAlgorithm
IRI | https://model.ccmm.cz/research-data/ChecksumAlgorithm
Label | Checksum algorithm
Definition | Algorithm used for Checksums.
Profiles | class profile Checksum Algorithm (https://mff-uk.github.io/specifications/dcat-ap#ChecksumAlgorithm) class profile Checksum Algorithm (https://mff-uk.github.io/specifications/dcat-dap#ChecksumAlgorithm) class without assigned name (spdx:ChecksumAlgorithm) Definition: Algorighm for Checksums.

Backwards associations

- from domain →

#### Contact details

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#ContactDetails
IRI | https://model.ccmm.cz/research-data/ContactDetails
Label | Contact details
Definition | Details to contact the agent in a relationship to the resource.
Profiles | class Contact details (https://model.ccmm.cz/vocabulary/ccmm#ContactDetails) Definition: Contact details such as telephone, e-mail address etc.
Usage note | Describes contact details, such as telephone, e--mail address etc.

Backwards associations

- from domain →

#### data box

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#dataBox
IRI | https://model.ccmm.cz/research-data/ContactDetails.dataBox
Label | data box
Definition | Code of the data box.
Domain | Contact details [0..*]
Range | xsd:string [0..*]
Profiles | property Data box (https://model.ccmm.cz/vocabulary/ccmm#dataBox) Definition: Data box code
Usage note |

#### email

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#email
IRI | https://model.ccmm.cz/research-data/ContactDetails.email
Label | email
Definition | Email address.
Domain | Contact details [0..*]
Range | xsd:string [0..*]
Profiles | property Email (https://model.ccmm.cz/vocabulary/ccmm#email) Definition: Email address
Usage note | Email address in standard format, e.g. john.doe@domain.com

#### has address

Profiled relationship IRI(s) | vcard:hasAddress
IRI | https://model.ccmm.cz/research-data/ContactDetails.hasAddress
Label | has address
Definition | To specify the components of the delivery address for the object
Domain | Contact details
Range | Address [0..*]
Profiles | property has address (vcard:hasAddress) Definition: To specify the components of the delivery address for the object
Usage note | Either links to IRI of address in address registry or describes the address using Address class attributes.

#### phone

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#phone
IRI | https://model.ccmm.cz/research-data/ContactDetails.phone
Label | phone
Definition | Phone number
Domain | Contact details [0..*]
Range | xsd:string [0..*]
Profiles | property Phone (https://model.ccmm.cz/vocabulary/ccmm#phone) Definition: Phone number
Usage note | Phone number in international format +xx(x) xxx xxx xxx

#### Data service

Profiled class IRI(s) | dcat:DataService
IRI | https://model.ccmm.cz/research-data/DataService
Label | Data service
Definition | A collection of operations that provides access to one or more datasets or data processing functions.
Profiles | class profile Data service (https://mff-uk.github.io/specifications/dcat-ap#DataService) class profile Data service (https://mff-uk.github.io/specifications/dcat-dap#DataService) Definition: A collection of operations that provides access to one or more datasets or data processing functions. class Data service (dcat:DataService) Definition: A site or end-point providing operations related to the discovery of, access to, or processing functions on, data or related resources.

Backwards associations

- from domain →

#### endpoint URL

Profiled relationship IRI(s) | dcat:endpointURL
IRI | https://model.ccmm.cz/research-data/DataService.endpointUrl
Label | endpoint URL
Definition | The root location or primary endpoint of the service (an IRI).
Domain | Data service
Range | Resource [1..*]
Profiles | property profile endpoint URL (https://mff-uk.github.io/specifications/dcat-ap#DataService.endpointUrl) Definition: The root location or primary endpoint of the service (an IRI). property profile endpoint URL (https://mff-uk.github.io/specifications/dcat-dap#DataService.endpointUrl) property service end-point (dcat:endpointURL) Definition: The root location or primary endpoint of the service (a web-resolvable IRI).

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/DataService.label
Label | label
Definition | Data service label
Domain | Data service [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Dataset

Profiled class IRI(s) | dcat:Dataset
IRI | https://model.ccmm.cz/research-data/Dataset
Label | Dataset
Definition | A collection of data, published or curated by a single source, and available for access or download in one or more representations.
Profiles | class Dataset (dcat:Dataset) Definition: A collection of data, published or curated by a single source, and available for access or download in one or more representations.

Backwards associations

- from domain →

#### has alternate title

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasAlternateTitle
IRI | https://model.ccmm.cz/research-data/Dataset.hasAlternateTitle
Label | has alternate title
Domain | Dataset
Range | Alternate title [0..*]
Profiles | property has alternate title (https://model.ccmm.cz/vocabulary/ccmm#hasAlternateTitle) Definition:

#### has description

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#hasDescription
IRI | https://model.ccmm.cz/research-data/Dataset.hasDescription
Label | has description
Definition | Relation to the description of a dataset.
Domain | Dataset
Range | Description [0..*]
Profiles | property has description (https://model.ccmm.cz/vocabulary/datacite#hasDescription) Definition:
Usage note | Description may have various type from the codelist https://vocabs.ccmm.cz/registry/codelist/DescriptionType/.

#### has distribution

Profiled relationship IRI(s) | dcat:distribution
IRI | https://model.ccmm.cz/research-data/Dataset.hasDistribution
Label | has distribution
Definition | An available Distribution for the Dataset.
Domain | Dataset
Range | Distribution [0..*]
Profiles | property profile dataset distribution (https://mff-uk.github.io/specifications/dcat-ap#Dataset.datasetDistribution) Definition: An available Distribution for the Dataset. property profile distribution (https://mff-uk.github.io/specifications/dcat-dap#Dataset.distribution) property distribution (dcat:distribution) Definition: An available distribution of the dataset.
Usage note | For the distribution of data in the form of files use instances of class Distribution – downloadable file. For the distribution of data through service use instance of class Distribution – data service.

#### has funding reference

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#hasFundingReference
IRI | https://model.ccmm.cz/research-data/Dataset.hasFundingReference
Label | has funding reference
Definition | Has reference for funding of a dataset acquisition.
Domain | Dataset
Range | Funding reference [0..*]
Profiles | property has funding reference (https://model.ccmm.cz/vocabulary/datacite#hasFundingReference) Definition:

#### has identifier

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier
IRI | https://model.ccmm.cz/research-data/Dataset.hasIdentifier
Label | has identifier
Definition | has identifier
Domain | Dataset
Range | Identifier [1..*]
Profiles | property has identifier (https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier) Definition: has identifier

#### has location

Profiled relationship IRI(s) | dcterms:spatial
IRI | https://model.ccmm.cz/research-data/Dataset.hasLocation
Label | has location
Definition | The geographical area covered by the dataset.
Domain | Dataset
Range | Location [0..*]
Profiles | property profile geographical coverage (https://mff-uk.github.io/specifications/dcat-ap#Dataset.geographicalCoverage) property profile spatial/geographical coverage (https://mff-uk.github.io/specifications/dcat-dap#Dataset.spatial-geographicalCoverage) Definition: The geographical area covered by the dataset. property Spatial Coverage (dcterms:spatial) Definition: Spatial characteristics of the resource.
Usage note | In the CCMM spatial coverage does not only cover the area of dataset, it may be connected to the dataset in some other way, e.g. the place from where the data were measured, administrative area to which the dataset conforms or other.

#### has other language

Profiled relationship IRI(s) | dcterms:language
IRI | https://model.ccmm.cz/research-data/Dataset.hasOtherLanguage
Label | has other language
Definition | Any other languages of the Dataset.
Domain | Dataset
Range | Language system [0..*]
Profiles | property profile language (https://mff-uk.github.io/specifications/dcat-ap#Dataset.language) Definition: A language of the Dataset. property profile language (https://mff-uk.github.io/specifications/dcat-dap#CataloguedResource.language) Definition: A language of the resource. This refers to the natural language used for textual metadata (i.e., titles, descriptions, etc.) of a cataloged resource (i.e., dataset or service) or the textual values of a dataset distribution property Language (dcterms:language) Definition: A language of the resource.
Usage note | This property can be repeated if there are multiple languages in the Dataset.

#### has primary language

Profiled relationship IRI(s) | dcterms:language
IRI | https://model.ccmm.cz/research-data/Dataset.hasPrimaryLanguage
Label | has primary language
Definition | A primary language of the Dataset.
Domain | Dataset
Range | Language system [0..1]
Profiles | property profile language (https://mff-uk.github.io/specifications/dcat-ap#Dataset.language) Definition: A language of the Dataset. property profile language (https://mff-uk.github.io/specifications/dcat-dap#CataloguedResource.language) Definition: A language of the resource. This refers to the natural language used for textual metadata (i.e., titles, descriptions, etc.) of a cataloged resource (i.e., dataset or service) or the textual values of a dataset distribution property Language (dcterms:language) Definition: A language of the resource.

#### has provenance

Profiled relationship IRI(s) | dcterms:provenance
IRI | https://model.ccmm.cz/research-data/Dataset.hasProvenance
Label | has provenance
Definition | A statement about the lineage of a Dataset.
Domain | Dataset
Range | Provenance Statement [0..*]
Profiles | property profile provenance (https://mff-uk.github.io/specifications/dcat-ap#Dataset.provenance) Definition: A statement about the lineage of a Dataset. property Provenance (dcterms:provenance) Definition: A statement of any changes in ownership and custody of the resource since its creation that are significant for its authenticity, integrity, and interpretation.

#### has related resource

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasRelatedResource
IRI | https://model.ccmm.cz/research-data/Dataset.hasRelatedResource
Label | has related resource
Definition | Reference to the resource in any way related to the described dataset.
Domain | Dataset
Range | Resource [0..*]
Profiles | property has related resource (https://model.ccmm.cz/vocabulary/ccmm#hasRelatedResource) Definition:

#### has resource type

Profiled relationship IRI(s) | dcterms:type
IRI | https://model.ccmm.cz/research-data/Dataset.resourceType
Label | has resource type
Definition | A resource type of the Dataset.
Domain | Dataset
Range | Resource type [0..1]
Profiles | property profile type (https://mff-uk.github.io/specifications/dcat-ap#Dataset.type) Definition: A type of the Dataset. property profile type/genre (https://mff-uk.github.io/specifications/dcat-dap#CataloguedResource.type-genre) property Type (dcterms:type) Definition: The nature or genre of the resource.
Usage note | Use IRI identifier of a value from the register https://vocabularies.coar-repositories.org/resource_types/.

#### has subject

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#hasSubject
IRI | https://model.ccmm.cz/research-data/Dataset.hasSubject
Label | has subject
Definition | Dataset described using a subject.
Domain | Dataset
Range | Subject [1..*]
Profiles | property has subject (https://model.ccmm.cz/vocabulary/datacite#hasSubject) Definition:
Usage note | At least one subject must be a value from FRASCATI FORD vocabulary. For that subject use reference codelist https://vocabs.ccmm.cz/registry/codelist/SubjectCategory/ as the Subject scheme and select at least one value from this codelist as a subject.

#### has terms of use

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#hasVersion
IRI | https://model.ccmm.cz/research-data/Dataset.hasTermsOfUse
Label | has terms of use
Definition | Terms under which the dataset may be accessed.
Domain | Dataset
Range | Terms of use [1..1]
Profiles | property has version (https://model.ccmm.cz/vocabulary/datacite#hasVersion) Definition:

#### has time reference

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasTimeReference
IRI | https://model.ccmm.cz/research-data/Dataset.hasTimeReference
Label | has time reference
Definition | Reference to events related to the dataset.
Domain | Dataset
Range | Time reference [1..*]
Profiles | property has time reference (https://model.ccmm.cz/vocabulary/ccmm#hasTimeReference) Definition:
Usage note | Must contain at least one time reference with date type value "Created" from https://vocabs.ccmm.cz/registry/codelist/TimeReference/.

#### has validation result

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasValidationResult
IRI | https://model.ccmm.cz/research-data/Dataset.hasValidationResult
Label | has validation result
Definition | Reference to the report about the dataset validation.
Domain | Dataset
Range | Validation result [0..*]
Profiles | property has validation result (https://model.ccmm.cz/vocabulary/ccmm#hasValidationResult) Definition:

#### is described by

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#isDescribedBy
IRI | https://model.ccmm.cz/research-data/Dataset.isDescribedBy
Label | is described by
Definition | Inverse relation between dataset and metadata record.
Domain | Dataset
Range | Metadata Record [1..*]
Profiles | property is described by (https://model.ccmm.cz/vocabulary/ccmm#isDescribedBy) Definition: Inverse relation between dataset and metadata record.

#### publication year

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#relatedItemPublicationYear
IRI | https://model.ccmm.cz/research-data/Dataset.publicationYear
Label | publication year
Definition | The year when the item was or will be made publicly available.
Domain | Dataset [0..*]
Range | xsd:gYear [1..1]
Profiles | property publication year (https://model.ccmm.cz/vocabulary/datacite#relatedItemPublicationYear) Definition: The year when the item was or will be made publicly available.
Usage note | If TimeReference with dateType "Issued" is present, year in that date and publicationYear must be the same“

#### qualified relation

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#qualifiedRelation
IRI | https://model.ccmm.cz/research-data/Dataset.qualifiedRelation
Label | qualified relation
Definition | Link to a description of a relationship between dataset and an agent with the specification of the role of agent in this relationship.
Domain | Dataset
Range | Resource to agent relationship [1..*]
Profiles | property qualified relation (https://model.ccmm.cz/vocabulary/ccmm#qualifiedRelation) Definition:
Usage note | Description of relationship between dataset and agent (e.g. creator, publisher, etc.). Role in a relationship is given by the Resource agent role type. Use a value from vocabulary https://vocabs.ccmm.cz/registry/codelist/AgentRole/. Each dataset shall have at least two qualified relations: one with role "Creator" and second with role "Publisher". If metadata manager is the same for dataset and metadata, it shall also have at least one qualified relation with role "data manager".

#### title

Profiled relationship IRI(s) | dcterms:title
IRI | https://model.ccmm.cz/research-data/Dataset.title
Label | title
Definition | A name given to the dataset.
Domain | Dataset [1..1]
Range | xsd:string [1..1]
Profiles | property Title (dcterms:title) Definition: A name given to the resource.

#### version

Profiled relationship IRI(s) | dcat:version
IRI | https://model.ccmm.cz/research-data/Dataset.version
Label | version
Definition | The version indicator (name or identifier) of a resource.
Domain | Dataset [0..*]
Range | xsd:string [0..1]
Profiles | property profile version (https://mff-uk.github.io/specifications/dcat-ap#Dataset.version) property profile version (https://mff-uk.github.io/specifications/dcat-dap#CataloguedResource.version) property version (dcat:version) Definition: The version indicator (name or identifier) of a resource.

#### Date type

Profiled class IRI(s) | skos:Concept
IRI | https://model.ccmm.cz/research-data/DateType
Label | Date type
Definition | Type of a date in relation to the resource.
Profiles | class Concept (skos:Concept) Definition: An idea or notion; a unit of thought.
Usage note | Use value from codelist https://vocabs.ccmm.cz/registry/codelist/TimeReference/.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/DateType.label
Label | label
Definition | Date type label.
Domain | Date type
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Description

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/datacite#Description
IRI | https://model.ccmm.cz/research-data/Description
Label | Description
Definition | All additional information that does not fit in any of the other categories. May be used for technical information or detailed information associated with a scientific instrument.
Profiles | class Description (https://model.ccmm.cz/vocabulary/datacite#Description) Definition: All additional information that does not fit in any of the other categories. May be used for technical information or detailed information associated with a scientific instrument.
Usage note | Description of the resource may have also a description type.

Backwards associations

- from domain →

#### description text

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#descriptionText
IRI | https://model.ccmm.cz/research-data/Description.descriptionText
Label | description text
Definition | Text describing the resource.
Domain | Description [0..*]
Range | xsd:string [1..1]
Profiles | property description text (https://model.ccmm.cz/vocabulary/datacite#descriptionText) Definition: Text describing the resource.

#### has description type

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#hasDescriptionType
IRI | https://model.ccmm.cz/research-data/Description.hasDescriptionType
Label | has description type
Definition | Relation to the type of the description.
Domain | Description
Range | Description type [0..1]
Profiles | property has description type (https://model.ccmm.cz/vocabulary/datacite#hasDescriptionType) Definition: Relation to the type of the description.
Usage note | Type of the description from the codelist https://vocabs.ccmm.cz/registry/codelist/DescriptionType/.

#### Description type

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/datacite#DescriptionType
IRI | https://model.ccmm.cz/research-data/DescriptionType
Label | Description type
Definition | The type of the description.
Profiles | class Description type (https://model.ccmm.cz/vocabulary/datacite#DescriptionType) Definition: The type of the description.
Usage note | Use value from codelist https://vocabs.ccmm.cz/registry/codelist/DescriptionType/.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/DescriptionType.label
Label | label
Definition | Label of the description type.
Domain | Description type
Range | xsd:string [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Distribution

Profiled class IRI(s) | dcat:Distribution
IRI | https://model.ccmm.cz/research-data/Distribution
Label | Distribution
Definition | A specific representation of a dataset. A dataset might be available in multiple serializations that may differ in various ways, including natural language, media-type or format, schematic organization, temporal and spatial resolution, level of detail or profiles (which might specify any or all of the above).
Profiles | class profile Distribution (https://mff-uk.github.io/specifications/dcat-ap#Distribution) class profile Distribution (https://mff-uk.github.io/specifications/dcat-dap#Distribution) class Distribution (dcat:Distribution) Definition: A specific representation of a dataset. A dataset might be available in multiple serializations that may differ in various ways, including natural language, media-type or format, schematic organization, temporal and spatial resolution, level of detail or profiles (which might specify any or all of the above).
Usage note | This represents a general availability of a dataset. It implies no information about the actual access method of the data, i.e., whether by direct download, API, or through a Web page. This is an abstract type. Use its subclasses to determine downloadable file or data service.

Backwards associations

- from domain →

#### title

Profiled relationship IRI(s) |
IRI | https://model.ccmm.cz/research-data/Distribution.title
Label | title
Domain | Distribution [0..*]
Range | rdf:langString [1..1]

#### Distribution - data service

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#Distribution-DataService
IRI | https://model.ccmm.cz/research-data/Distribution-DataService
Label | Distribution - data service
Definition | Physical embodiment of the dataset distribution as a particular data service.
Profiles | class Distribution - data service (https://model.ccmm.cz/vocabulary/ccmm#Distribution-DataService) Definition: Physical embodiment of the dataset as a particular data service.

#### conforms to specification

Profiled relationship IRI(s) | dcterms:conformsTo
IRI | https://model.ccmm.cz/research-data/Distribution-DataService.conformsToSpecification
Label | conforms to specification
Definition | An established standard to which the distribution conforms.
Domain | Distribution - data service
Range | Application profile [0..*]
Profiles | property profile linked schemas (https://mff-uk.github.io/specifications/dcat-ap#Distribution.linkedSchemas) property profile conforms to (https://mff-uk.github.io/specifications/dcat-dap#Distribution.conformsTo) Definition: An established standard to which the distribution conforms. property Conforms To (dcterms:conformsTo) Definition: An established standard to which the described resource conforms.
Usage note | This property SHOULD be used to indicate the profile or specification that this data service conforms to. This is (generally) a complementary concern to the service standard.

#### description

Profiled relationship IRI(s) |
IRI | https://model.ccmm.cz/research-data/Distribution-DataService.Description
Label | description
Definition | A free-text account of the Distribution.
Domain | Distribution - data service [0..*]
Range | Text [0..*]
Usage note | This property can be repeated for parallel language versions of the description.

#### has access service

Profiled relationship IRI(s) | dcat:accessService
IRI | https://model.ccmm.cz/research-data/Distribution-DataService.hasAccessService
Label | has access service
Definition | A site or end-point that gives access to the distribution of the dataset.
Domain | Distribution - data service
Range | Data service [0..*]
Profiles | property profile access service (https://mff-uk.github.io/specifications/dcat-ap#Distribution.accessService) property profile access service (https://mff-uk.github.io/specifications/dcat-dap#Distribution.accessService) property data access service (dcat:accessService) Definition: A site or end-point that gives access to the distribution of the dataset.
Usage note | Access service SHOULD be used to link to a description of Data service that can provide access to this distribution.

#### has documentation

Profiled relationship IRI(s) | foaf:page
IRI | https://model.ccmm.cz/research-data/Distribution-DataService.hasDocumentation
Label | has documentation
Definition | A page or document about this Distribution.
Domain | Distribution - data service
Range | Documentation [0..*]
Profiles | property profile documentation (https://mff-uk.github.io/specifications/dcat-ap#Distribution.documentation) Definition: A page or document about this Distribution. property page (foaf:page) Definition: A page or document about this thing.

#### Distribution - downloadable file

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#Distribution-DownloadableFile
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile
Label | Distribution - downloadable file
Definition | Physical embodiment of the dataset in a particular format.
Profiles | class Distribution - downloadable file (https://model.ccmm.cz/vocabulary/ccmm#Distribution-DownloadableFile) Definition: Physical embodiment of the dataset in a particular format.

#### access URL

Profiled relationship IRI(s) | dcat:accessURL
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.accessUrl
Label | access URL
Definition | A URL that gives access to a Distribution of the Dataset.
Domain | Distribution - downloadable file
Range | File [1..*]
Profiles | property profile access URL (https://mff-uk.github.io/specifications/dcat-ap#Distribution.accessUrl) Definition: A URL that gives access to a Distribution of the Dataset. property profile access URL (https://mff-uk.github.io/specifications/dcat-dap#Distribution.accessUrl) Definition: A URL of the resource that gives access to a distribution of the dataset. E.g., landing page, feed, SPARQL endpoint. property access address (dcat:accessURL) Definition: A URL of a resource that gives access to a distribution of the dataset. E.g. landing page, feed, SPARQL endpoint. Use for all cases except a simple download link, in which case downloadURL is preferred.
Usage note | The resource at the access URL contains information about how to get the Dataset. It shall be the web page (not a document file).

#### byte size

Profiled relationship IRI(s) | dcat:byteSize
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.byteSize
Label | byte size
Definition | The size of a Distribution in bytes.
Domain | Distribution - downloadable file [0..*]
Range | xsd:integer [1..1]
Profiles | property profile byte size (https://mff-uk.github.io/specifications/dcat-ap#Distribution.byteSize) property profile byte size (https://mff-uk.github.io/specifications/dcat-dap#Distribution.byteSize) property byte size (dcat:byteSize) Definition: The size of a distribution in bytes.

#### conforms to schema

Profiled relationship IRI(s) | dcterms:conformsTo
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.conformsToSchema
Label | conforms to schema
Definition | An established standard to which the distribution conforms.
Domain | Distribution - downloadable file
Range | Application profile [0..*]
Profiles | property profile linked schemas (https://mff-uk.github.io/specifications/dcat-ap#Distribution.linkedSchemas) property profile conforms to (https://mff-uk.github.io/specifications/dcat-dap#Distribution.conformsTo) Definition: An established standard to which the distribution conforms. property Conforms To (dcterms:conformsTo) Definition: An established standard to which the described resource conforms.
Usage note | This property SHOULD be used to indicate the model, schema, ontology, view or profile that this representation of a dataset conforms to. This is (generally) a complementary concern to the media-type or format.

#### download URL

Profiled relationship IRI(s) | dcat:downloadURL
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.downloadUrl
Label | download URL
Definition | A URL that is a direct link to a downloadable file in a given format.
Domain | Distribution - downloadable file
Range | File [0..*]
Profiles | property profile download URL (https://mff-uk.github.io/specifications/dcat-ap#Distribution.downloadUrl) Definition: A URL that is a direct link to a downloadable file in a given format. property profile download URL (https://mff-uk.github.io/specifications/dcat-dap#Distribution.downloadUrl) property download URL (dcat:downloadURL) Definition: The URL of the downloadable file in a given format. E.g. CSV file or RDF file. The format is indicated by the distribution's dcterms:format and/or dcat:mediaType.
Usage note | Download URL SHOULD be used for the URL at which this distribution is available directly, typically through a HTTP Get request.

#### has checksum

Profiled relationship IRI(s) | spdx:checksum
IRI | https://model.ccmm.cz/research-data/Distribution-DataService.hasChecksum
Label | has checksum
Definition | A mechanism that can be used to verify that the contents of a distribution have not changed.
Domain | Distribution - downloadable file
Range | Checksum [0..1]
Profiles | property profile checksum (https://mff-uk.github.io/specifications/dcat-ap#Distribution.checksum) Definition: A mechanism that can be used to verify that the contents of a distribution have not changed. property profile checksum (https://mff-uk.github.io/specifications/dcat-dap#Distribution.checksum) property without assigned name (spdx:checksum) Definition: The checksum property provides a mechanism that can be used to verify that the contents of a File or Package have not changed.
Usage note | The checksum is related to the download URL.

#### has format

Profiled relationship IRI(s) | dcterms:format
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.hasFormat
Label | has format
Definition | The file format of the distribution.
Domain | Distribution - downloadable file
Range | Format [1..1]
Profiles | property profile format (https://mff-uk.github.io/specifications/dcat-ap#Distribution.format) property profile format (https://mff-uk.github.io/specifications/dcat-dap#Distribution.format) Definition: The file format of the distribution. property Format (dcterms:format) Definition: The file format, physical medium, or dimensions of the resource.
Usage note |

#### media type

Profiled relationship IRI(s) | dcat:mediaType
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.mediaType
Label | media type
Definition | The media type of the distribution as defined by IANA
Domain | Distribution - downloadable file
Range | Media Type [0..1]
Profiles | property profile media type (https://mff-uk.github.io/specifications/dcat-ap#Distribution.mediaType) property profile media type (https://mff-uk.github.io/specifications/dcat-dap#Distribution.mediaType) property media type (dcat:mediaType) Definition: The media type of the distribution as defined by IANA
Usage note | This property SHOULD be used when the media type of the distribution is defined in IANA (using value from https://www.iana.org/assignments/media-types/media-types.xhtml), otherwise Format MAY be used with values from Publication Office of the EU File type codelist http://publications.europa.eu/resource/dataset/file-type.

#### Documentation

Profiled class IRI(s) | foaf:Document
IRI | https://model.ccmm.cz/research-data/Documentation
Label | Documentation
Definition | A textual resource intended for human consumption that contains information about the data service.
Profiles | class profile Document (https://mff-uk.github.io/specifications/dcat-ap#Document) Definition: A textual resource intended for human consumption that contains information, e.g. a web page about a Dataset. class Document (foaf:Document) Definition: A document.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/Documentation.label
Label | label
Definition | Documentation label
Domain | Documentation [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### File

Profiled class IRI(s) | rdfs:Resource
IRI | https://model.ccmm.cz/research-data/File
Label | File
Definition | Digital resource representing collection of data.
Profiles | class profile Resource (https://mff-uk.github.io/specifications/dcat-ap#rdfs-Resource) Definition: Anything described by RDF. class profile Resource (https://mff-uk.github.io/specifications/dcat-dap#rdfs-Resource) class Resource (rdfs:Resource) Definition: The class resource, everything.
Usage note | File is represented by URL on which is it accessable.

Backwards associations

- from domain →
- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/File.label
Label | label
Definition | File label
Domain | File [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Format

Profiled class IRI(s) | dcterms:MediaTypeOrExtent
IRI | https://model.ccmm.cz/research-data/Format
Label | Format
Definition | Format of downloadable file.
Profiles | class profile Media Type or Extent (https://mff-uk.github.io/specifications/dcat-ap#MediaTypeOrExtent) class profile Media Type or Extent (https://mff-uk.github.io/specifications/dcat-dap#MediaTypeOrExtent) class Media Type or Extent (dcterms:MediaTypeOrExtent) Definition: A media type or extent.
Usage note | Use IRI identifier from the register http://publications.europa.eu/resource/dataset/file-type. Human readable codelist representation is here: https://op.europa.eu/en/web/eu-vocabularies/concept-scheme/-/resource?uri=http://publications.europa.eu/resource/authority/file-type.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/Format.label
Label | label
Definition | Label of format value.
Domain | Format
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.
Usage note | Use a label of a codelist value from http://publications.europa.eu/resource/dataset/file-type.

#### Funding reference

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/datacite#FundingReference
IRI | https://model.ccmm.cz/research-data/FundingReference
Label | Funding reference
Definition | Information about financial support (funding) for the resource being registered.
Profiles | class Funding reference (https://model.ccmm.cz/vocabulary/datacite#FundingReference) Definition: Information about financial support (funding) for the resource being registered.

Backwards associations

- from domain →

#### award title

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#awardTitle
IRI | https://model.ccmm.cz/research-data/FundingReference.awardTitle
Label | award title
Definition | The human readable title or name of the award (grant).
Domain | Funding reference [1..1]
Range | xsd:string [0..1]
Profiles | property award title (https://model.ccmm.cz/vocabulary/datacite#awardTitle) Definition: The human readable title or name of the award (grant).

#### funding program

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#fundingProgram
IRI | https://model.ccmm.cz/research-data/FundingReference.fundingProgram
Label | funding program
Definition | Reference to the specific funding program.
Domain | Funding reference [0..*]
Range | xsd:anyURI [0..1]
Profiles | property Funding program (https://model.ccmm.cz/vocabulary/ccmm#fundingProgram) Definition: Reference to the specific funding program.

#### has funder

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#hasFunderIdentifier
IRI | https://model.ccmm.cz/research-data/FundingReference.hasFunder
Label | has funder
Definition | Relation to the agent entity of a funder.
Domain | Funding reference
Range | Agent [1..*]
Profiles | property has funder identifier (https://model.ccmm.cz/vocabulary/datacite#hasFunderIdentifier) Definition:

#### local identifier

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#awardNumber
IRI | https://model.ccmm.cz/research-data/FundingReference.localIdentifier
Label | local identifier
Definition | The code assigned by the funder to a sponsored award (grant).
Domain | Funding reference [0..*]
Range | xsd:string [0..1]
Profiles | property award number (https://model.ccmm.cz/vocabulary/datacite#awardNumber) Definition: The code assigned by the funder to a sponsored award (grant).
Usage note | In case the award or grant has an ID or DOI, the full URL shall be included.

#### Geometry

Profiled class IRI(s) | locn:Geometry
IRI | https://model.ccmm.cz/research-data/Geometry
Label | Geometry
Definition | The Geometry class provides the means to identify a location as a point, line, polygon, etc. expressed using coordinates in some coordinate reference system.
Profiles | class profile Geometry (https://mff-uk.github.io/specifications/dcat-ap#Geometry) class profile Geometry (https://mff-uk.github.io/specifications/dcat-dap#Geometry) class Geometry (locn:Geometry) Definition:

Backwards associations

- from domain →

#### geography markup language literal

Profiled relationship IRI(s) | http://www.opengis.net/ont/geosparql#asGML
IRI | https://model.ccmm.cz/research-data/Geometry.geographyMarkupLanguageLiteral
Label | geography markup language literal
Definition | Representation of geometry object as GML Literal.
Domain | Geometry
Range | http://www.opengis.net/ont/geosparql#gmlLiteral [0..*]
Profiles | property gml (http://www.opengis.net/ont/geosparql#asGML) Definition:

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/Geometry.label
Label | label
Definition | Label of geometry object.
Domain | Geometry [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### well known text literal

Profiled relationship IRI(s) | http://www.opengis.net/ont/geosparql#asWKT
IRI | https://model.ccmm.cz/research-data/Geometry.wellKnownTextLiteral
Label | well known text literal
Definition | Representation of geometry object as WKT Literal.
Domain | Geometry
Range | http://www.opengis.net/ont/geosparql#wktLiteral [0..*]
Profiles | property wkt (http://www.opengis.net/ont/geosparql#asWKT) Definition:

#### Identifier

Profiled class IRI(s) | adms:Identifier
IRI | https://model.ccmm.cz/research-data/Identifier
Label | Identifier
Definition | Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.
Profiles | class Identifier (adms:Identifier) Definition: This class is based on the UN/CEFACT Identifier complex type defined in See Section 5.8 of Core Components Data Type Catalogue Version 3.1 (http://www.unece.org/fileadmin/DAM/cefact/codesfortrade/CCTS/CCTS-DTCatalogueVersion3p1.pdf) In RDF this is expressed using the following properties: - the content string should be provided using skos:notation, datatyped with the identifier scheme (inclduing the version number if appropriate); - use dcterms:creator to link to a class describing the agency that manages the identifier scheme or adms:schemaAgency to provide the name as a literal. Although not part of the ADMS conceptual model, it may be useful to provide further properties to the Identifier class such as dcterms:created to provide the date on which the identifier was issued.

Backwards associations

- from domain →
- from domain →
- from domain →

#### in scheme

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#inScheme
IRI | https://model.ccmm.cz/research-data/Identifier.inScheme
Label | in scheme
Definition | Relation between the identifier and scheme in which it is defined and unique.
Domain | Identifier
Range | Identifier scheme [1..1]
Profiles | property in scheme (https://model.ccmm.cz/vocabulary/ccmm#inScheme) Definition: Relation between the identifier and scheme in which it is defined and unique.

#### value

Profiled relationship IRI(s) | skos:notation
IRI | https://model.ccmm.cz/research-data/Identifier.value
Label | value
Definition | Value of the identifer within the given identifier scheme.
Domain | Identifier [0..*]
Range | xsd:string [1..1]
Profiles | property notation (skos:notation) Definition: A notation, also known as classification code, is a string of characters such as "T58.5" or "303.4833" used to uniquely identify a concept within the scope of a given concept scheme.

#### Identifier scheme

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#IdentifierScheme
IRI | https://model.ccmm.cz/research-data/IdentifierScheme
Label | Identifier scheme
Definition | Scheme in which is the identifier value unique, usually representing some authority. Identifier scheme shall always be represented as IRI identifier.
Profiles | class Identifier scheme (https://model.ccmm.cz/vocabulary/ccmm#IdentifierScheme) Definition: Scheme in which is the identifier value unique, usually representing some authority. Identifier scheme shall always be represented as IRI identifier.
Usage note | Use identifier scheme in the form of IRI identifier. Methodology shall list known sources.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/IdentifierScheme.label
Label | label
Definition | Identifier scheme label
Domain | Identifier scheme
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.
Usage note | E.g. DOI, ORCID etc...

#### Language system

Profiled class IRI(s) | dcterms:LinguisticSystem
IRI | https://model.ccmm.cz/research-data/LanguageSystem
Label | Language system
Definition | A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.
Profiles | class profile Linguistic System (https://mff-uk.github.io/specifications/dcat-ap#LinguisticSystem) Definition: A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language. class profile Linguistic System (https://mff-uk.github.io/specifications/dcat-dap#LinguisticSystem) class Linguistic System (dcterms:LinguisticSystem) Definition: A system of signs, symbols, sounds, gestures, or rules used in communication.
Usage note | Use IRI identifier from the register http://publications.europa.eu/resource/authority/language.

Backwards associations

- from domain →
- from domain →
- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/LanguageSystem.label
Label | label
Definition | Language label
Domain | Language system
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.
Usage note | Use language label and/or its 3-letter code from http://publications.europa.eu/resource/authority/language/.

#### License Document

Profiled class IRI(s) |
IRI | https://model.ccmm.cz/research-data/LicenseDocument
Label | License Document
Definition | A legal document giving official permission to do something with a resource.
Usage note |

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/LicenseDocument.label
Label | label
Definition | Label of the license document.
Domain | License Document
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Location

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/datacite#Geolocation dcterms:Location
IRI | https://model.ccmm.cz/research-data/Location
Label | Location
Definition | Spatial region, named place or geometry representation of a place related to the dataset.
Profiles | class GeoLocation (https://model.ccmm.cz/vocabulary/datacite#Geolocation) Definition: Spatial region or named place where the data was gathered or about which the data is focused. class profile Location (https://mff-uk.github.io/specifications/dcat-ap#Location) class profile Location (https://mff-uk.github.io/specifications/dcat-dap#Location) class Location (dcterms:Location) Definition: A spatial region or named place.
Usage note | Location is represented according to the Open Formal Standard for Spatial Data. Locations are represented as a reference to the named place, geographic region or specific geometry according to the standardized geometry object representation. Every Location instance must have at least one of the following attributes/relations: bbox, location name, geometry and/or related object identifier.

Backwards associations

- from domain →

#### bounding box

Profiled relationship IRI(s) | dcat:bbox
IRI | https://model.ccmm.cz/research-data/Location.bbox
Label | bounding box
Definition | Bounding box of the location geometry.
Domain | Location [0..*]
Range | Literal [0..*]
Profiles | property bounding box (dcat:bbox) Definition: The geographic bounding box of a spatial thing [SDW-BP].
Usage note | Typically defined by top-left and bottom-right corners.

#### has geometry

Profiled relationship IRI(s) | locn:geometry
IRI | https://model.ccmm.cz/research-data/Location.hasGeometry
Label | has geometry
Definition | The corresponding geometry for a resource.
Domain | Location
Range | Geometry [0..1]
Profiles | property profile geometry (https://mff-uk.github.io/specifications/dcat-ap#Location.geometry) Definition: The corresponding geometry for a resource. property profile geometry (https://mff-uk.github.io/specifications/dcat-dap#Location.geometry) Definition: Associates a spatial thing [SDW-BP] with a corresponding geometry. property geometry (locn:geometry) Definition: Associates any resource with the corresponding geometry.
Usage note | The range of this property allows for any type of geometry specification. E.g., the geometry could be encoded by a literal, as WKT (geosparql:wktLiteral), or represented by a class, as geosparql:Geometry (or any of its subclasses).

#### has location relation type

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasType
IRI | https://model.ccmm.cz/research-data/Location.hasLocationRelationType
Label | has location relation type
Definition | Relation of the location to the dataset.
Domain | Location
Range | Location relation type [1..1]
Profiles | property has type (https://model.ccmm.cz/vocabulary/ccmm#hasType) Definition: Reference to the codelist value giving the specific type to the attribute.
Usage note | Use values from codelist https://vocabs.ccmm.cz/registry/codelist/LocationRelation/.

#### has related object

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasRelatedResource
IRI | https://model.ccmm.cz/research-data/Location.hasRelatedObject
Label | has related object
Definition | Relation to the spatial object.
Domain | Location
Range | Resource [0..*]
Profiles | property has related resource (https://model.ccmm.cz/vocabulary/ccmm#hasRelatedResource) Definition:
Usage note | The relation is provided by the identifier of the related object. It shall be identifier of an existing spatial object in a registry, such as Place Named Authority List (http://publications.europa.eu/resource/authority/place), Register of Territorial Identification, Addresses and Real Estates or others.

#### name

Profiled relationship IRI(s) | dcterms:title
IRI | https://model.ccmm.cz/research-data/Location.name
Label | name
Definition | Name of the spatial location.
Domain | Location [0..*]
Range | Text [0..*]
Profiles | property Title (dcterms:title) Definition: A name given to the resource.
Usage note | Name of the place. Examples: Prague Castle, Tour d'Eiffel, Šumava National Park

#### Location relation type

Profiled class IRI(s) | skos:Concept
IRI | https://model.ccmm.cz/research-data/LocationRelationType
Label | Location relation type
Definition | Relation of the dataset to the resource.
Profiles | class Concept (skos:Concept) Definition: An idea or notion; a unit of thought.
Usage note | Use value from codelist https://vocabs.ccmm.cz/registry/codelist/LocationRelation/.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/LocationRelationType.label
Label | label
Definition | Label of location relation type.
Domain | Location relation type
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Media Type

Profiled class IRI(s) | dcterms:MediaType
IRI | https://model.ccmm.cz/research-data/MediaType
Label | Media Type
Definition | A file format.
Profiles | class profile Media Type (https://mff-uk.github.io/specifications/dcat-ap#MediaType) class profile Media Type (https://mff-uk.github.io/specifications/dcat-dap#MediaType) class Media Type (dcterms:MediaType) Definition: A file format or physical medium.
Usage note | Use IRI value from registry https://www.iana.org/assignments/media-types/media-types.xhtml.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/MediaType.label
Label | label
Definition | Media type label.
Domain | Media Type [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Metadata Record

Profiled class IRI(s) | dcat:CatalogRecord
IRI | https://model.ccmm.cz/research-data/MetadataRecord
Label | Metadata Record
Definition | Description of the metadata record of the dataset.
Profiles | class profile Catalogue Record (https://mff-uk.github.io/specifications/dcat-ap#CatalogueRecord) class profile Catalog Record (https://mff-uk.github.io/specifications/dcat-dap#CatalogRecord) Definition: A record in a catalog, describing the registration of a single dcat:Resource. class Catalog Record (dcat:CatalogRecord) Definition: A record in a data catalog, describing the registration of a single dataset or data service.
Usage note | In case metadata is harvested from external catalogue, metadata record IRI shall be the same as IRI of the metadata record in original repository.

Backwards associations

- from domain →

#### conforms to standard

Profiled relationship IRI(s) | dcterms:conformsTo
IRI | https://model.ccmm.cz/research-data/MetadataRecord.conformsToStandard
Label | conforms to standard
Definition | An established standard to which the metadata record conforms.
Domain | Metadata Record
Range | Application profile [0..*]
Profiles | property profile conforms to (https://mff-uk.github.io/specifications/dcat-dap#CatalogRecord.conformsTo) property Conforms To (dcterms:conformsTo) Definition: An established standard to which the described resource conforms.
Usage note | This property SHOULD be used to indicate the standard or profile that was used to describe cataloged resource content.

#### date created

Profiled relationship IRI(s) | dcterms:created
IRI | https://model.ccmm.cz/research-data/MetadataRecord.dateCreated
Label | date created
Definition | The date on which the metadata record was created.
Domain | Metadata Record [0..*]
Range | xsd:date [0..1]
Profiles | property Date Created (dcterms:created) Definition: Date of creation of the resource.

#### date updated

Profiled relationship IRI(s) | dcterms:modified
IRI | https://model.ccmm.cz/research-data/MetadataRecord.dateUpdated
Label | date updated
Definition | Date on which the resource was changed.
Domain | Metadata Record [0..*]
Range | xsd:date [0..*]
Profiles | property Date Modified (dcterms:modified) Definition: Date on which the resource was changed.
Usage note | The date on which the metadata record was changed or modified.

#### describes

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#describes
IRI | https://model.ccmm.cz/research-data/MetadataRecord.describes
Label | describes
Definition | Dataset described by the metadata record.
Domain | Metadata Record
Range | Dataset [0..*]
Profiles | property describes (https://model.ccmm.cz/vocabulary/ccmm#describes) Definition: Dataset described by the metadata record.

#### has original repository

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#originalRepository
IRI | https://model.ccmm.cz/research-data/MetadataRecord.hasOriginalRepository
Label | has original repository
Definition | Link to the repository in which the metadata were originally stored and curated.
Domain | Metadata Record
Range | Repository [0..*]
Profiles | property original repository (https://model.ccmm.cz/vocabulary/ccmm#originalRepository) Definition: Link to the repository from which the metadata were originally stored and curated.

#### language

Profiled relationship IRI(s) | dcterms:language
IRI | https://model.ccmm.cz/research-data/MetadataRecord.hasLanguage
Label | language
Definition | A language used in the textual metadata describing titles, descriptions of the metadata record.
Domain | Metadata Record
Range | Language system [0..*]
Profiles | property profile language (https://mff-uk.github.io/specifications/dcat-ap#CatalogueRecord.language) Definition: A language used in the textual metadata describing titles, descriptions, etc. of the Catalogued Resource. property Language (dcterms:language) Definition: A language of the resource.
Usage note | This property can be repeated if the metadata is provided in multiple languages.

#### qualified relation

Profiled relationship IRI(s) |
IRI | https://model.ccmm.cz/research-data/MetadataRecord.qualifiedRelation
Label | qualified relation
Definition | Link to a description of a relationship between metadata record and agent with the specification of the role of agent in this relationship.
Domain | Metadata Record
Range | Resource to agent relationship [1..*]
Usage note | Relationship shall contain at least one agent with role "Data Manager" from codelist https://vocabs.ccmm.cz/registry/codelist/AgentRole/.

#### Organization

Profiled class IRI(s) | prov:Organization foaf:Agent
IRI | https://model.ccmm.cz/research-data/Organization
Label | Organization
Definition | Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures.
Profiles | class Organization (prov:Organization) Definition: class profile Agent (https://mff-uk.github.io/specifications/dcat-ap#Agent) Definition: Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources. class profile Agent (https://mff-uk.github.io/specifications/dcat-dap#Agent) class Agent (foaf:Agent) Definition: An agent (eg. person, group, software or physical artifact).

Backwards associations

- from domain →

#### alternate name

Profiled relationship IRI(s) | vcard:organization-name
IRI | https://model.ccmm.cz/research-data/Organization.alternateName
Label | alternate name
Definition | To specify the organizational name associated with the object
Domain | Organization [0..*]
Range | Text [0..*]
Profiles | property organization name (vcard:organization-name) Definition: To specify the organizational name associated with the object

#### Person

Profiled class IRI(s) | prov:Person
IRI | https://model.ccmm.cz/research-data/Person
Label | Person
Definition | Physical person.
Profiles | class Person (prov:Person) Definition:
Usage note |

#### family name

Profiled relationship IRI(s) | vcard:family-name
IRI | https://model.ccmm.cz/research-data/Person.familyName
Label | family name
Definition | The family name associated with the person.
Domain | Person [0..*]
Range | xsd:string [0..*]
Profiles | property family name (vcard:family-name) Definition: The family name associated with the object

#### given name

Profiled relationship IRI(s) | vcard:given-name
IRI | https://model.ccmm.cz/research-data/Person.givenName
Label | given name
Definition | The given name associated with the person.
Domain | Person [0..*]
Range | xsd:string [0..*]
Profiles | property given name (vcard:given-name) Definition: The given name associated with the object

#### has affiliation

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasAffiliation
IRI | https://model.ccmm.cz/research-data/Person.hasAffiliation
Label | has affiliation
Definition | Affiliation of the person to an organization.
Domain | Person
Range | Organization [0..*]
Profiles | property has affiliation (https://model.ccmm.cz/vocabulary/ccmm#hasAffiliation) Definition:

#### Provenance Statement

Profiled class IRI(s) | dcterms:ProvenanceStatement
IRI | https://model.ccmm.cz/research-data/ProvenanceStatement
Label | Provenance Statement
Definition | Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.
Profiles | class profile Provenance Statement (https://mff-uk.github.io/specifications/dcat-ap#ProvenanceStatement) class Provenance Statement (dcterms:ProvenanceStatement) Definition: Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/ProvenanceStatement.label
Label | label
Definition | Provenance state label.
Domain | Provenance Statement [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Repository

Profiled class IRI(s) | dcat:Catalog
IRI | https://model.ccmm.cz/research-data/Repository
Label | Repository
Definition | A catalogue or repository that hosts the Datasets or Data Services being described.
Profiles | class profile Catalogue (https://mff-uk.github.io/specifications/dcat-ap#Catalogue) Definition: A catalogue or repository that hosts the Datasets or Data Services being described. class profile Catalog (https://mff-uk.github.io/specifications/dcat-dap#Catalog) Definition: A curated collection of metadata about resources. class Catalog (dcat:Catalog) Definition: A curated collection of metadata about resources (e.g., datasets and data services in the context of a data catalog).

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/Repository.label
Label | label
Definition | Human readable name of the repository.
Domain | Repository [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Resource

Profiled class IRI(s) | rdfs:Resource
IRI | https://model.ccmm.cz/research-data/Resource
Label | Resource
Definition | Resource represents any resource, physical or digital, that is related to the described dataset.
Profiles | class Resource (rdfs:Resource) Definition: The class resource, everything.
Usage note | Class is used for description of the resource together with the type of relation, for which is used value from codelist https://vocabs.ccmm.cz/registry/codelist/RelationType/. Distributions of the datasets SHALL NOT be modeled as related resource, but as a distribution. Use qualified resource property to link to the dataset class. Examples of resources: other related dataset, used methodology, instrument used for measurement, conference or conference paper etc...

Backwards associations

- from domain →
- from domain →
- from domain →

#### has identifier

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier
IRI | https://model.ccmm.cz/research-data/Resource.hasIdentifier
Label | has identifier
Definition | Relation to resource identifier.
Domain | Resource
Range | Identifier [0..*]
Profiles | property has identifier (https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier) Definition: has identifier

#### has resource relation type

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasType
IRI | https://model.ccmm.cz/research-data/Resource.hasResourceRelationType
Label | has resource relation type
Definition | Relation to the relation type between dataset and resource.
Domain | Resource
Range | Resource relation type [0..1]
Profiles | property has type (https://model.ccmm.cz/vocabulary/ccmm#hasType) Definition: Reference to the codelist value giving the specific type to the attribute.
Usage note | Use value from https://vocabs.ccmm.cz/registry/codelist/RelationType/.

#### has resource type

Profiled relationship IRI(s) | dcterms:type
IRI | https://model.ccmm.cz/research-data/Resource.type
Label | has resource type
Definition | A resource type of the related resource.
Domain | Resource
Range | Resource type [0..1]
Profiles | property Type (dcterms:type) Definition: The nature or genre of the resource.
Usage note | Use IRI identifier of a value from the register https://vocabularies.coar-repositories.org/resource_types/.

#### has time reference

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasTimeReference
IRI | https://model.ccmm.cz/research-data/Resource.hasTimeReference
Label | has time reference
Definition | Reference to events related to the resource.
Domain | Resource
Range | Time reference [0..*]
Profiles | property has time reference (https://model.ccmm.cz/vocabulary/ccmm#hasTimeReference) Definition:

#### qualified relation

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#qualifiedRelation
IRI | https://model.ccmm.cz/research-data/Resource.qualifiedRelation
Label | qualified relation
Definition | Link to a description of a relationship between resource and an agent with the specification of the role of agent in this relationship.
Domain | Resource
Range | Resource to agent relationship [0..*]
Profiles | property qualified relation (https://model.ccmm.cz/vocabulary/ccmm#qualifiedRelation) Definition:
Usage note |

#### resource URL

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#resourceUrl
IRI | https://model.ccmm.cz/research-data/Resource.resourceURL
Label | resource URL
Definition | Resolvable URL representing the resource, preferably human readable.
Domain | Resource [0..*]
Range | xsd:anyURI [0..1]
Profiles | property Resource URL (https://model.ccmm.cz/vocabulary/ccmm#resourceUrl) Definition: Resolvable URL representing the resource, preferably human readable.
Usage note | In case it is filled, it must be filled the same in c:iri. If there are more resolvable IRIs, Resource URL shall link to human readable version, machine readable ID is always in c:iri.

#### title

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#relatedItemTitle
IRI | https://model.ccmm.cz/research-data/Resource.title
Label | title
Definition | Title of the resource related to the dataset.
Domain | Resource [0..*]
Range | xsd:string [0..1]
Profiles | property title (https://model.ccmm.cz/vocabulary/datacite#relatedItemTitle) Definition: Title of the related item.

#### Resource agent role type

Profiled class IRI(s) | skos:Concept
IRI | https://model.ccmm.cz/research-data/ResourceAgentRoleType
Label | Resource agent role type
Definition | Role of the agent in the relationship to the resource.
Profiles | class Concept (skos:Concept) Definition: An idea or notion; a unit of thought.
Usage note | Use value from code list https://vocabs.ccmm.cz/registry/codelist/AgentRole/.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/ResourceAgentRoleType.label
Label | label
Definition | Resource agent role type label.
Domain | Resource agent role type [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.
Usage note | Use label of the corresponding value from code list https://vocabs.ccmm.cz/registry/codelist/AgentRole/.

#### Resource relation type

Profiled class IRI(s) | skos:Concept
IRI | https://model.ccmm.cz/research-data/ResourceRelationType
Label | Resource relation type
Definition | Type of the relation between the dataset and given resource.
Profiles | class Concept (skos:Concept) Definition: An idea or notion; a unit of thought.
Usage note | Use value from the codelist https://vocabs.ccmm.cz/registry/codelist/RelationType/.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/ResourceRelationType.label
Label | label
Definition | Label of the relation type.
Domain | Resource relation type
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.
Usage note | Use label of corresponding value from code list https://vocabs.ccmm.cz/registry/codelist/RelationType/.

#### Resource to agent relationship

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#ResourceToAgentRelationship
IRI | https://model.ccmm.cz/research-data/ResourceToAgentRelationship
Label | Resource to agent relationship
Definition | An association class for attaching additional information to a relationship between Resource and Agent.
Profiles | class Resource to agent relationship (https://model.ccmm.cz/vocabulary/ccmm#ResourceToAgentRelationship) Definition: An association class for attaching additional information to a relationship between Dataset and Agent.
Usage note | Use to characterize a relationship between resources and agents, where the nature of the relationship is known but is not adequately characterized by the standard DCTERMS properties (dcterms:hasPart, dcterms:isPartOf, dcterms:conformsTo, dcterms:isFormatOf, dcterms:hasFormat, dcterms:isVersionOf, dcterms:hasVersion, dcterms:replaces, dcterms:isReplacedBy, dcterms:references, dcterms:isReferencedBy, dcterms:requires, dcterms:isRequiredBy) or PROV-O properties (prov:wasDerivedFrom, prov:wasInfluencedBy, prov:wasQuotedFrom, prov:wasRevisionOf, prov:hadPrimarySource, prov:alternateOf, prov:specializationOf). Roles of the agent in the relation are specified using had role relation.

Backwards associations

- from domain →
- from domain →
- from domain →

#### had role

Profiled relationship IRI(s) | dcat:hadRole
IRI | https://model.ccmm.cz/research-data/ResourceToAgentRelationship.hadRole
Label | had role
Definition | The function of an entity or agent with respect to another entity or resource.
Domain | Resource to agent relationship
Range | Resource agent role type [1..1]
Profiles | property profile had role (https://mff-uk.github.io/specifications/dcat-ap#Relationship.hadRole) property profile had role (https://mff-uk.github.io/specifications/dcat-dap#Relationship.hadRole) property hadRole (dcat:hadRole) Definition: The function of an entity or agent with respect to another entity or resource.
Usage note | May be used in a qualified-attribution to specify the role of an Agent with respect to an Entity. It is recommended that the value be taken from a controlled vocabulary of agent roles.

#### has related agent

Profiled relationship IRI(s) | dcterms:relation
IRI | https://model.ccmm.cz/research-data/ResourceToAgentRelationship.hasRelatedAgent
Label | has related agent
Definition | Specifies the agent an a given role in the relationship with the resource.
Domain | Resource to agent relationship
Range | Agent [1..1]
Profiles | property profile relation (https://mff-uk.github.io/specifications/dcat-ap#Relationship.relation) property profile relation (https://mff-uk.github.io/specifications/dcat-dap#Relationship.relation) Definition: The resource related to the source resource. property Relation (dcterms:relation) Definition: A related resource.

#### Resource type

Profiled class IRI(s) | skos:Concept
IRI | https://model.ccmm.cz/research-data/ResourceType
Label | Resource type
Definition | Type of the resource.
Profiles | class Concept (skos:Concept) Definition: An idea or notion; a unit of thought.
Usage note | Use IRI identifier of the resource type from the codelist https://vocabularies.coar-repositories.org/resource_types/.

Backwards associations

- from domain →
- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/ResourceType.label
Label | label
Definition | Label of the resource type.
Domain | Resource type
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Subject

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/datacite#Subject
IRI | https://model.ccmm.cz/research-data/Subject
Label | Subject
Definition | Subject, keyword, classification code, or key phrase describing the resource.
Profiles | class Subject (https://model.ccmm.cz/vocabulary/datacite#Subject) Definition: Subject, keyword, classification code, or key phrase describing the resource.
Usage note | Recommended approach is to use controlled list values, preferably in the form of IRI.

Backwards associations

- from domain →

#### classification code

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#subjectClassificationCode
IRI | https://model.ccmm.cz/research-data/Subject.classificationCode
Label | classification code
Definition | The classification code used for notation of the subject term in the subject scheme.
Domain | Subject [0..*]
Range | xsd:string [0..1]
Profiles | property subject classification code (https://model.ccmm.cz/vocabulary/datacite#subjectClassificationCode) Definition: The classification code used for the subject term in the subject scheme.

#### definition

Profiled relationship IRI(s) | skos:definition
IRI | https://model.ccmm.cz/research-data/Subject.definition
Label | definition
Definition | Definition of the subject in the given context.
Domain | Subject [0..*]
Range | Text [0..*]
Profiles | property definition (skos:definition) Definition: A statement or formal explanation of the meaning of a concept.
Usage note | Context is usually given by the subject scheme representing specific thesauri, vocabulary or simply a context (domain specific group at an university etc.).

#### in subject scheme

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#inSubjectScheme
IRI | https://model.ccmm.cz/research-data/Subject.inSubjectScheme
Label | in subject scheme
Definition | Belonging of the subject to the subject scheme.
Domain | Subject
Range | Subject scheme [0..1]
Profiles | property in subject scheme (https://model.ccmm.cz/vocabulary/ccmm#inSubjectScheme) Definition:

#### title

Profiled relationship IRI(s) | dcterms:title
IRI | https://model.ccmm.cz/research-data/Subject.title
Label | title
Definition | Title of the subject.
Domain | Subject [0..*]
Range | rdf:langString [1..*]
Profiles | property Title (dcterms:title) Definition: A name given to the resource.

#### Subject scheme

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#SubjectScheme
IRI | https://model.ccmm.cz/research-data/SubjectScheme
Label | Subject scheme
Definition | Collection of subjects (keywords, concepts, classification codes) curated by a single source.
Profiles | class Subject scheme (https://model.ccmm.cz/vocabulary/ccmm#SubjectScheme) Definition: Collection of subjects (keywords, concepts, classification codes) curated by a single source.
Usage note | Subject scheme sets a contexts for all subjects within this scheme. It usually represents thesauri, vocabulary etc., but may also represent a set of concepts with the meaning of the same context, such as domain specific nomenclature.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/SubjectScheme.label
Label | label
Definition | Label of the subject scheme.
Domain | Subject scheme [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

#### Terms of use

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/datacite#Rights
IRI | https://model.ccmm.cz/research-data/TermsOfUse
Label | Terms of use
Definition | Terms of use defines overall conditions and rights regarding access and usage of dataset.
Profiles | class Rights (https://model.ccmm.cz/vocabulary/datacite#Rights) Definition: Any rights information for this resource. The property may be repeated to record complex rights characteristics.
Usage note |

Backwards associations

- from domain →

#### access rights

Profiled relationship IRI(s) | dcterms:accessRights
IRI | https://model.ccmm.cz/research-data/TermsOfUse.accessRights
Label | access rights
Definition | Information about the conditions to access the resource or an indication of its security status.
Domain | Terms of use
Range | Access rights [1..1]
Profiles | property Access Rights (dcterms:accessRights) Definition: Information about who access the resource or an indication of its security status.

#### description

Profiled relationship IRI(s) | dcterms:description
IRI | https://model.ccmm.cz/research-data/TermsOfUse.Description
Label | description
Definition | Descriptive text on details of rights and licensing.
Domain | Terms of use [0..*]
Range | Text [0..*]
Profiles | property Description (dcterms:description) Definition: An account of the resource.

#### has contact point

Profiled relationship IRI(s) | dcat:contactPoint
IRI | https://model.ccmm.cz/research-data/TermsOfUse.hasContactPoint
Label | has contact point
Definition | Contact point for the further details about the terms of use.
Domain | Terms of use
Range | Agent [0..*]
Profiles | property contact point (dcat:contactPoint) Definition: Relevant contact information for the catalogued resource. Use of vCard is recommended.

#### has license

Profiled relationship IRI(s) | dcterms:license
IRI | https://model.ccmm.cz/research-data/TermsOfUse.license
Label | has license
Definition | Reference to the legal document giving official permission to do something with the resource.
Domain | Terms of use
Range | License Document [1..1]
Profiles | property License (dcterms:license) Definition: A legal document giving official permission to do something with the resource.

#### Time instant

Profiled class IRI(s) | time:Instant
IRI | https://model.ccmm.cz/research-data/TimeInstant
Label | Time instant
Definition | A temporal entity with zero extent or duration.
Profiles | class Time instant (time:Instant) Definition: A temporal entity with zero extent or duration
Usage note | Use for representation of time reference with zero extent or duration.

Backwards associations

- from domain →
- from domain →

#### date

Profiled relationship IRI(s) | time:inXSDDate
IRI | https://model.ccmm.cz/research-data/TimeInstant.date
Label | date
Definition | Position of an instant, expressed using xsd:date.
Domain | Time instant
Range | xsd:date [0..1]
Profiles | property in XSD date (time:inXSDDate) Definition: Position of an instant, expressed using xsd:date
Usage note | Each time instant SHALL have exactly one date OR date time stamp attribute.

#### date time

Profiled relationship IRI(s) | time:inXSDDateTime
IRI | https://model.ccmm.cz/research-data/TimeInstant.dateTime
Label | date time
Definition | Date with timestamp represented as xsd:dateTime.
Domain | Time instant
Range | xsd:dateTime [0..1]
Profiles | property in XSD Date-Time (time:inXSDDateTime) Definition: Position of an instant, expressed using xsd:dateTime
Usage note | Each time instant SHALL have exactly one date OR date time attribute. Maintanance note: In the draft on newest version of Time ontology, in XSD date-time is deprecated and replaced with in XSD date-time-stamp.

#### Time interval

Profiled class IRI(s) | time:Interval
IRI | https://model.ccmm.cz/research-data/TimeInterval
Label | Time interval
Definition | A temporal entity with an extent or duration
Profiles | class Time interval (time:Interval) Definition: A temporal entity with an extent or duration
Usage note | Use for representation of time reference represented as an interval. Interval is represented by beginning and end time instants.

#### has beginning

Profiled relationship IRI(s) | time:hasBeginning
IRI | https://model.ccmm.cz/research-data/TimeInterval.hasBeginning
Label | has beginning
Definition | Time instant representing the beginning of a temporal interval.
Domain | Time interval
Range | Time instant [1..1]
Profiles | property has beginning (time:hasBeginning) Definition: Beginning of a temporal entity

#### has end

Profiled relationship IRI(s) | time:hasEnd
IRI | https://model.ccmm.cz/research-data/TimeInterval.hasEnd
Label | has end
Definition | Time instant representing the end of a temporal interval.
Domain | Time interval
Range | Time instant [1..1]
Profiles | property has end (time:hasEnd) Definition: End of a temporal entity.

#### Time reference

Profiled class IRI(s) | time:TemporalEntity
IRI | https://model.ccmm.cz/research-data/TimeReference
Label | Time reference
Definition | A temporal interval or instant on which something relevant to the resource has happened.
Profiles | class Temporal entity (time:TemporalEntity) Definition: A temporal interval or instant.

Backwards associations

- from domain →
- from domain →

#### date information

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/datacite#dateInformation
IRI | https://model.ccmm.cz/research-data/TimeReference.dateInformation
Label | date information
Definition | Additional information to the date in text form.
Domain | Time reference [0..*]
Range | Text [0..1]
Profiles | property date information (https://model.ccmm.cz/vocabulary/datacite#dateInformation) Definition: Specific information about the date, if appropriate.
Usage note | Write any additional information needed to understand the meaning of event that happened in the given time.

#### has date type

Profiled relationship IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#hasType
IRI | https://model.ccmm.cz/research-data/TimeReference.hasDateType
Label | has date type
Definition | Reference to the codelist of date types.
Domain | Time reference
Range | Date type [1..1]
Profiles | property has type (https://model.ccmm.cz/vocabulary/ccmm#hasType) Definition: Reference to the codelist value giving the specific type to the attribute.
Usage note |

#### Validation result

Profiled class IRI(s) | https://model.ccmm.cz/vocabulary/ccmm#ValidationResult
IRI | https://model.ccmm.cz/research-data/ValidationResult
Label | Validation result
Definition | Class describing the result of validation testing. It may include validation of metadata, data and/or web services accessing the data.
Profiles | class Validation result (https://model.ccmm.cz/vocabulary/ccmm#ValidationResult) Definition: Class describing the result of validation testing. It may include validation of metadata, data and/or web services accessing the data.

Backwards associations

- from domain →

#### label

Profiled relationship IRI(s) | rdfs:label
IRI | https://model.ccmm.cz/research-data/ValidationResult.label
Label | label
Definition | Label of the validation result.
Domain | Validation result [0..*]
Range | rdf:langString [0..*]
Profiles | property label (rdfs:label) Definition: A human-readable name for the subject.

## Specifikace struktury pro Agent

Data structure for Agent. Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Agent, jež je definováno v souboru `../agent/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../identifier/schema.xsd |
Stejný namespace jako hlavní dokument | ../contact-details/schema.xsd |
Stejný namespace jako hlavní dokument | ../organization/schema.xsd |

#### Kořenové entity XSD schématu

- element `agent`
- komplexní typ `agent`

#### Kořenový element `<agent>`

Typ elementu
Obsah
  Obsahem elementu je typ `agent`.

#### Kořenový komplexní typ `agent`

Obsah - výběr jednoho elementu z množiny

- element `<organization>` [1..1]
- element `<person>` [1..1]

#### Element `<organization>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<name>` [1..1]
- element `<alternate_name>` [0..*]
- element `<identifier>` [0..*]
- element `<contact_point>` [0..*]

#### Element `<organization>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<organization>` / `<name>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost name (Name of the agent.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<organization>` / `<alternate_name>`

Význam
  vlastnost alternate name (To specify the organizational name associated with the object)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<organization>` / `<identifier>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost has identifier (has identifier)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.
Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)

#### Element `<organization>` / `<contact_point>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost has contact point (Relevant contact information for the catalogued resource. )
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `contact_details`.
Význam
  Contact details (Details to contact the agent in a relationship to the resource.)

#### Element `<person>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Person (Physical person. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<name>` [1..1]
- element `<given_name>` [0..*]
- element `<family_name>` [0..*]
- element `<identifier>` [0..*]
- element `<contact_point>` [0..*]
- element `<affiliation>` [0..*]

#### Element `<person>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<person>` / `<name>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost name (Name of the agent.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<person>` / `<given_name>`

Význam
  vlastnost given name (The given name associated with the person.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<person>` / `<family_name>`

Význam
  vlastnost family name (The family name associated with the person.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<person>` / `<identifier>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost has identifier (has identifier)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.
Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)

#### Element `<person>` / `<contact_point>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost has contact point (Relevant contact information for the catalogued resource. )
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `contact_details`.
Význam
  Contact details (Details to contact the agent in a relationship to the resource.)

#### Element `<person>` / `<affiliation>`

Význam
  vlastnost has affiliation (Affiliation of the person to an organization.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `organization`.
Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )

## Specifikace struktury pro Distribution

Data structure for Distribution. A specific representation of a dataset. A dataset might be available in multiple serializations that may differ in various ways, including natural language, media-type or format, schematic organization, temporal and spatial resolution, level of detail or profiles (which might specify any or all of the above).

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Distribution, jež je definováno v souboru `../distribution/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../documentation/schema.xsd |
Stejný namespace jako hlavní dokument | ../application-profile/schema.xsd |
Stejný namespace jako hlavní dokument | ../data-service/schema.xsd |
Stejný namespace jako hlavní dokument | ../checksum/schema.xsd |
Stejný namespace jako hlavní dokument | ../media-type/schema.xsd |
Stejný namespace jako hlavní dokument | ../file/schema.xsd |
Stejný namespace jako hlavní dokument | ../format/schema.xsd |

#### Kořenové entity XSD schématu

- element `distribution`
- komplexní typ `distribution`

#### Kořenový element `<distribution>`

Typ elementu
Obsah
  Obsahem elementu je typ `distribution`.

#### Kořenový komplexní typ `distribution`

Obsah - výběr jednoho elementu z množiny

- element `<distribution_-_data_service>` [1..1]
- element `<distribution_-_downloadable_file>` [1..1]

#### Element `<distribution_-_data_service>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Distribution - data service (Physical embodiment of the dataset distribution as a particular data service. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<title>` [1..1]
- element `<description>` [0..*]
- element `<documentation>` [0..*]
- element `<specification>` [0..*]
- element `<access_service>` [0..*]

#### Element `<distribution_-_data_service>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<distribution_-_data_service>` / `<title>`

Význam
  z obecnější třídy Distribution (A specific representation of a dataset. A dataset might be available in multiple serializations that may differ in various ways, including natural language, media-type or format, schematic organization, temporal and spatial resolution, level of detail or profiles (which might specify any or all of the above).) → mající vlastnost title
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<distribution_-_data_service>` / `<description>`

Význam
  vlastnost description (A free-text account of the Distribution.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<distribution_-_data_service>` / `<documentation>`

Význam
  vlastnost has documentation (A page or document about this Distribution.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `documentation`.
Význam
  Documentation (A textual resource intended for human consumption that contains information about the data service.)

#### Element `<distribution_-_data_service>` / `<specification>`

Význam
  vlastnost conforms to specification (An established standard to which the distribution conforms.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `application_profile`.
Význam
  Application profile (A standard or other specification to which a metadata record conforms.)

#### Element `<distribution_-_data_service>` / `<access_service>`

Význam
  vlastnost has access service (A site or end-point that gives access to the distribution of the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `data_service`.
Význam
  Data service (A collection of operations that provides access to one or more datasets or data processing functions.)

#### Element `<distribution_-_downloadable_file>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Distribution - downloadable file (Physical embodiment of the dataset in a particular format. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<title>` [1..1]
- element `<byte_size>` [1..1]
- element `<checksum>` [0..1]
- element `<conforms_to_schema>` [0..*]
- element `<media_type>` [0..1]
- element `<access_url>` [1..*]
- element `<download_url>` [0..*]
- element `<format>` [1..1]

#### Element `<distribution_-_downloadable_file>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<distribution_-_downloadable_file>` / `<title>`

Význam
  z obecnější třídy Distribution (A specific representation of a dataset. A dataset might be available in multiple serializations that may differ in various ways, including natural language, media-type or format, schematic organization, temporal and spatial resolution, level of detail or profiles (which might specify any or all of the above).) → mající vlastnost title
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<distribution_-_downloadable_file>` / `<byte_size>`

Význam
  vlastnost byte size (The size of a Distribution in bytes. )
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:integer`.

#### Element `<distribution_-_downloadable_file>` / `<checksum>`

Význam
  vlastnost has checksum (A mechanism that can be used to verify that the contents of a distribution have not changed.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `checksum`.
Význam
  Checksum (A value that allows the contents of a file to be authenticated.)

#### Element `<distribution_-_downloadable_file>` / `<conforms_to_schema>`

Význam
  vlastnost conforms to schema (An established standard to which the distribution conforms.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `application_profile`.
Význam
  Application profile (A standard or other specification to which a metadata record conforms.)

#### Element `<distribution_-_downloadable_file>` / `<media_type>`

Význam
  vlastnost media type (The media type of the distribution as defined by IANA)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `media_type`.
Význam
  Media Type (A file format.)

#### Element `<distribution_-_downloadable_file>` / `<access_url>`

Význam
  vlastnost access URL (A URL that gives access to a Distribution of the Dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `file`.
Význam
  File (Digital resource representing collection of data.)

#### Element `<distribution_-_downloadable_file>` / `<download_url>`

Význam
  vlastnost download URL (A URL that is a direct link to a downloadable file in a given format.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `file`.
Význam
  File (Digital resource representing collection of data.)

#### Element `<distribution_-_downloadable_file>` / `<format>`

Význam
  vlastnost has format (The file format of the distribution.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `format`.
Význam
  Format (Format of downloadable file.)

## Specifikace struktury pro Contact details

Data structure for Contact details. Contact details such as telephone, e-mail address etc.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Contact details, jež je definováno v souboru `../contact-details/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../address/schema.xsd |

#### Kořenové entity XSD schématu

- element `contact_details`
- komplexní typ `contact_details`

#### Kořenový element `<contact_details>`

Typ elementu
Obsah
  Obsahem elementu je typ `contact_details`.

#### Kořenový komplexní typ `contact_details`

Význam
  Contact details (Details to contact the agent in a relationship to the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<dataBox>` [0..*]
- element `<email>` [0..*]
- element `<phone>` [0..*]
- element `<address>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<dataBox>`

Význam
  vlastnost data box (Code of the data box.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<email>`

Význam
  vlastnost email (Email address.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<phone>`

Význam
  vlastnost phone (Phone number)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<address>`

Význam
  vlastnost has address (To specify the components of the delivery address for the object)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `address`.
Význam
  Address (A spatial object that in a human-readable way identifies a fixed location. )

## Specifikace struktury pro Resource

Data structure for Resource. Resource represents any resource, physical or digital, that is related to the described dataset.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Resource, jež je definováno v souboru `../resource/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../resource-to-agent-relationship/schema.xsd |
Stejný namespace jako hlavní dokument | ../time_reference/schema.xsd |
Stejný namespace jako hlavní dokument | ../identifier/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource-type/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource-relation-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `resource`
- komplexní typ `resource`

#### Kořenový element `<resource>`

Typ elementu
Obsah
  Obsahem elementu je typ `resource`.

#### Kořenový komplexní typ `resource`

Význam
  Resource (Resource represents any resource, physical or digital, that is related to the described dataset. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<title>` [0..1]
- element `<resource_url>` [0..1]
- element `<qualified_relation>` [0..*]
- element `<time_reference>` [0..*]
- element `<identifier>` [0..*]
- element `<resource_type>` [0..1]
- element `<resource_relation_type>` [0..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<title>`

Význam
  vlastnost title (Title of the resource related to the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<resource_url>`

Význam
  vlastnost resource URL (Resolvable URL representing the resource, preferably human readable.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<qualified_relation>`

Význam
  vlastnost qualified relation (Link to a description of a relationship between resource and an agent with the specification of the role of agent in this relationship.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_to_agent_relationship`.
Význam
  Resource to agent relationship (An association class for attaching additional information to a relationship between Resource and Agent.)

#### Element `<time_reference>`

Význam
  vlastnost has time reference (Reference to events related to the resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_reference`.
Význam
  Time interval (A temporal entity with an extent or duration)

#### Element `<identifier>`

Význam
  vlastnost has identifier (Relation to resource identifier.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.
Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)

#### Element `<resource_type>`

Význam
  vlastnost has resource type (A resource type of the related resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_type`.
Význam
  Resource type (Type of the resource.)

#### Element `<resource_relation_type>`

Význam
  vlastnost has resource relation type (Relation to the relation type between dataset and resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_relation_type`.
Význam
  Resource relation type (Type of the relation between the dataset and given resource.)

## Specifikace struktury pro Location

Data structure for Location. Spatial region, named place or geometry representation of a place related to the dataset.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Location, jež je definováno v souboru `../location/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../geometry/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource/schema.xsd |
Stejný namespace jako hlavní dokument | ../location-relation-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `location`
- komplexní typ `location`

#### Kořenový element `<location>`

Typ elementu
Obsah
  Obsahem elementu je typ `location`.

#### Kořenový komplexní typ `location`

Význam
  Location (Spatial region, named place or geometry representation of a place related to the dataset. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<bounding_box>` [0..*]
- element `<name>` [0..*]
- element `<geometry>` [0..1]
- element `<related_object>` [0..*]
- element `<relation_type>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<bounding_box>`

Význam
  vlastnost bounding box (Bounding box of the location geometry.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anySimpleType`.

#### Element `<name>`

Význam
  vlastnost name (Name of the spatial location.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<geometry>`

Význam
  vlastnost has geometry (The corresponding geometry for a resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `geometry`.
Význam
  Geometry (The Geometry class provides the means to identify a location as a point, line, polygon, etc. expressed using coordinates in some coordinate reference system.)

#### Element `<related_object>`

Význam
  vlastnost has related object (Relation to the spatial object.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource`.
Význam
  Resource (Resource represents any resource, physical or digital, that is related to the described dataset. )

#### Element `<relation_type>`

Význam
  vlastnost has location relation type (Relation of the location to the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `relation_type`.
Význam
  Location relation type (Relation of the dataset to the resource.)

## Specifikace struktury pro Time reference

Data structure for Time reference. A temporal interval or instant on which something relevant to the resource has happened.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Time reference, jež je definováno v souboru `../time_reference/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../time-instant/schema.xsd |
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../date-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `time_reference`
- komplexní typ `time_reference`

#### Kořenový element `<time_reference>`

Typ elementu
Obsah
  Obsahem elementu je typ `time_reference`.

#### Kořenový komplexní typ `time_reference`

Obsah - výběr jednoho elementu z množiny

- element `<time_interval>` [1..1]
- element `<time_instant>` [1..1]

#### Element `<time_interval>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Time interval (A temporal entity with an extent or duration)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<beginning_time_instant>` [1..1]
- element `<end_time_instant>` [1..1]
- element `<date_information>` [0..1]
- element `<date_type>` [1..1]

#### Element `<time_interval>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<time_interval>` / `<beginning_time_instant>`

Význam
  vlastnost has beginning (Time instant representing the beginning of a temporal interval.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_instant`.
Význam
  Time instant (A temporal entity with zero extent or duration.)

#### Element `<time_interval>` / `<end_time_instant>`

Význam
  vlastnost has end (Time instant representing the end of a temporal interval.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_instant`.
Význam
  Time instant (A temporal entity with zero extent or duration.)

#### Element `<time_interval>` / `<date_information>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost date information (Additional information to the date in text form.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<time_interval>` / `<date_type>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost has date type (Reference to the codelist of date types.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `date_type`.
Význam
  Date type (Type of a date in relation to the resource.)

#### Element `<time_instant>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Time instant (A temporal entity with zero extent or duration.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<date_information>` [0..1]
- element `<date_type>` [1..1]
- výběr jednoho prvku [1..1]
  - element `<date_time>` [1..1]
  - element `<date>` [1..1]

#### Element `<time_instant>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<time_instant>` / `<date_information>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost date information (Additional information to the date in text form.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<time_instant>` / `<date_type>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost has date type (Reference to the codelist of date types.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `date_type`.
Význam
  Date type (Type of a date in relation to the resource.)

#### Element `<time_instant>` / `<date_time>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:dateTime`.

#### Element `<time_instant>` / `<date>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:date`.

## Specifikace struktury pro Funding reference

Data structure for Funding reference. Information about financial support (funding) for the resource being registered.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Funding reference, jež je definováno v souboru `../funding-reference/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../agent/schema.xsd |

#### Kořenové entity XSD schématu

- element `funding_reference`
- komplexní typ `funding_reference`

#### Kořenový element `<funding_reference>`

Typ elementu
Obsah
  Obsahem elementu je typ `funding_reference`.

#### Kořenový komplexní typ `funding_reference`

Význam
  Funding reference (Information about financial support (funding) for the resource being registered.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<funding_program>` [0..1]
- element `<award_title>` [0..1]
- element `<local_identifier>` [0..1]
- element `<funder>` [1..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<funding_program>`

Význam
  vlastnost funding program (Reference to the specific funding program.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<award_title>`

Význam
  vlastnost award title ( The human readable title or name of the award (grant).)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<local_identifier>`

Význam
  vlastnost local identifier (The code assigned by the funder to a sponsored award (grant).)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<funder>`

Význam
  vlastnost has funder (Relation to the agent entity of a funder.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `agent`.
Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )

## Specifikace struktury pro Terms of use

Data structure for Terms of use. Terms of use defines overall conditions and rights regarding access and usage of dataset.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Terms of use, jež je definováno v souboru `../terms-of-use/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../access-rights/schema.xsd |
Stejný namespace jako hlavní dokument | ../license-document/schema.xsd |
Stejný namespace jako hlavní dokument | ../agent/schema.xsd |

#### Kořenové entity XSD schématu

- element `terms_of_use`
- komplexní typ `terms_of_use`

#### Kořenový element `<terms_of_use>`

Typ elementu
Obsah
  Obsahem elementu je typ `terms_of_use`.

#### Kořenový komplexní typ `terms_of_use`

Význam
  Terms of use (Terms of use defines overall conditions and rights regarding access and usage of dataset. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<description>` [0..*]
- element `<access_rights>` [1..1]
- element `<license>` [1..1]
- element `<contact_point>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<description>`

Význam
  vlastnost description (Descriptive text on details of rights and licensing.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<access_rights>`

Význam
  vlastnost access rights (Information about the conditions to access the resource or an indication of its security status.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `access_rights`.
Význam
  Access rights (A statement about the access rights to the dataset.)

#### Element `<license>`

Význam
  vlastnost has license (Reference to the legal document giving official permission to do something with the resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `license_document`.
Význam
  License Document (A legal document giving official permission to do something with a resource.)

#### Element `<contact_point>`

Význam
  vlastnost has contact point (Contact point for the further details about the terms of use.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `agent`.
Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )

## Specifikace struktury pro Resource to Agent Relationship

Data structure for Resource to Agent Relationship. An association class for attaching additional information to a relationship between Dataset and Agent.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Resource to Agent Relationship, jež je definováno v souboru `../resource-to-agent-relationship/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../agent/schema.xsd |

#### Kořenové entity XSD schématu

- element `resource_to_agent_relationship`
- komplexní typ `resource_to_agent_relationship`

#### Kořenový element `<resource_to_agent_relationship>`

Typ elementu
Obsah
  Obsahem elementu je typ `resource_to_agent_relationship`.

#### Kořenový komplexní typ `resource_to_agent_relationship`

Význam
  Resource to agent relationship (An association class for attaching additional information to a relationship between Resource and Agent.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<role>` [1..1]
- element `<relation>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<role>`

Význam
  vlastnost had role (The function of an entity or agent with respect to another entity or resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<relation>`

Význam
  vlastnost has related agent (Specifies the agent an a given role in the relationship with the resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `agent`.
Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )

## Specifikace struktury pro Resource agent role type

Data structure for Resource agent role type. An idea or notion; a unit of thought.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Resource agent role type, jež je definováno v souboru `../resource-agent-role-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Nic není importováno.

#### Kořenové entity XSD schématu

- element `resource_agent_role_type`
- komplexní typ `resource_agent_role_type`

#### Kořenový element `<resource_agent_role_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `resource_agent_role_type`.

#### Kořenový komplexní typ `resource_agent_role_type`

Význam
  Resource agent role type (Role of the agent in the relationship to the resource. )
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

## Specifikace struktury pro Application profile

Data structure for Application profile. A standard or other specification to which a metadata record conforms.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Application profile, jež je definováno v souboru `../application-profile/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `application_profile`
- komplexní typ `application_profile`

#### Kořenový element `<application_profile>`

Typ elementu
Obsah
  Obsahem elementu je typ `application_profile`.

#### Kořenový komplexní typ `application_profile`

Význam
  Application profile (A standard or other specification to which a metadata record conforms.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of application profile)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Media Type

Data structure for Media Type. A file format or physical medium.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Media Type, jež je definováno v souboru `../media-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `media_type`
- komplexní typ `media_type`

#### Kořenový element `<media_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `media_type`.

#### Kořenový komplexní typ `media_type`

Význam
  Media Type (A file format.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Media type label.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro File

Data structure for File. Downloadable file in given format.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro File, jež je definováno v souboru `../file/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `file`
- komplexní typ `file`

#### Kořenový element `<file>`

Typ elementu
Obsah
  Obsahem elementu je typ `file`.

#### Kořenový komplexní typ `file`

Význam
  File (Digital resource representing collection of data.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (File label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Validation result

Data structure for Validation result. Class describing the result of validation testing. It may include validation of metadata, data and/or web services accessing the data.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Validation result, jež je definováno v souboru `../validation-result/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `validation_result`
- komplexní typ `validation_result`

#### Kořenový element `<validation_result>`

Typ elementu
Obsah
  Obsahem elementu je typ `validation_result`.

#### Kořenový komplexní typ `validation_result`

Význam
  Validation result (Class describing the result of validation testing. It may include validation of metadata, data and/or web services accessing the data.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the validation result.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Subject scheme

Data structure for Subject scheme. Collection of subjects (keywords, concepts, classification codes) curated by a single source.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Subject scheme, jež je definováno v souboru `../subject-scheme/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `subject_scheme`
- komplexní typ `subject_scheme`

#### Kořenový element `<subject_scheme>`

Typ elementu
Obsah
  Obsahem elementu je typ `subject_scheme`.

#### Kořenový komplexní typ `subject_scheme`

Význam
  Subject scheme (Collection of subjects (keywords, concepts, classification codes) curated by a single source.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the subject scheme.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Address

Data structure for Address. An "address representation" as conceptually defined by the INSPIRE Address Representation data type. The locn:addressId property may be used to link this locn:Address to other representations.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Address, jež je definováno v souboru `../address/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `address`
- komplexní typ `address`

#### Kořenový element `<address>`

Typ elementu
Obsah
  Obsahem elementu je typ `address`.

#### Kořenový komplexní typ `address`

Význam
  Address (A spatial object that in a human-readable way identifies a fixed location. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<label>` [0..*]
- element `<full_address>` [0..*]
- element `<po_box>` [0..*]
- element `<thoroughfare>` [0..*]
- element `<locator_designator>` [0..*]
- element `<locator_name>` [0..*]
- element `<address_area>` [0..*]
- element `<post_name>` [0..*]
- element `<administrative_unit_level_1>` [0..*]
- element `<administrative_unit_level_2>` [0..*]
- element `<post_code>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Address label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<full_address>`

Význam
  vlastnost full address (The complete address written as a string.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<po_box>`

Význam
  vlastnost post office box (A location designator for a postal delivery point at a post office, usually a number.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<thoroughfare>`

Význam
  vlastnost thoroughfare (The name of a passage or way through from one location to another.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<locator_designator>`

Význam
  vlastnost locator designator (A number or sequence of characters that uniquely identifies the locator within the relevant scope.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<locator_name>`

Význam
  vlastnost locator name (Proper noun(s) applied to the real world entity identified by the locator. The locator name could be the name of the property or complex, of the building or part of the building, or it could be the name of a room inside a building.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<address_area>`

Význam
  vlastnost address area (The name of a geographic area that groups Addresses.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<post_name>`

Význam
  vlastnost post name (A name created and maintained for postal purposes to identify a subdivision of addresses and postal delivery points. )
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<administrative_unit_level_1>`

Význam
  vlastnost administrative unit level 1 (The name of the uppermost level of the address, almost always a country.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<administrative_unit_level_2>`

Význam
  vlastnost administrative unit level 2 (The name of a secondary level/region of the address, usually a county, state or other such area that typically encompasses several localities.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<post_code>`

Význam
  vlastnost post code (The code created and maintained for postal purposes to identify a subdivision of addresses and postal delivery points.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

## Specifikace struktury pro Provenance Statement

Data structure for Provenance Statement. Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Provenance Statement, jež je definováno v souboru `../provenance-statement/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `provenance_statement`
- komplexní typ `provenance_statement`

#### Kořenový element `<provenance_statement>`

Typ elementu
Obsah
  Obsahem elementu je typ `provenance_statement`.

#### Kořenový komplexní typ `provenance_statement`

Význam
  Provenance Statement (Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Provenance state label.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Media Type

Data structure for Media Type. A file format or physical medium.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Media Type, jež je definováno v souboru `../media-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `media_type`
- komplexní typ `media_type`

#### Kořenový element `<media_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `media_type`.

#### Kořenový komplexní typ `media_type`

Význam
  Media Type (A file format.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Media type label.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Subject

Data structure for Subject. Subject, keyword, classification code, or key phrase describing the resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Subject, jež je definováno v souboru `../subject/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../subject-scheme/schema.xsd |

#### Kořenové entity XSD schématu

- element `subject`
- komplexní typ `subject`

#### Kořenový element `<subject>`

Typ elementu
Obsah
  Obsahem elementu je typ `subject`.

#### Kořenový komplexní typ `subject`

Význam
  Subject (Subject, keyword, classification code, or key phrase describing the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<definition>` [0..*]
- element `<title>` [1..*]
- element `<classification_code>` [0..1]
- element `<subject_scheme>` [0..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<definition>`

Význam
  vlastnost definition (Definition of the subject in the given context.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<title>`

Význam
  vlastnost title (Title of the subject.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<classification_code>`

Význam
  vlastnost classification code (The classification code used for notation of the subject term in the subject scheme.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<subject_scheme>`

Význam
  vlastnost in subject scheme (Belonging of the subject to the subject scheme.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `subject_scheme`.
Význam
  Subject scheme (Collection of subjects (keywords, concepts, classification codes) curated by a single source.)

## Specifikace struktury pro Metadata Record

Data structure for Metadata Record. Description of the metadata record of the dataset.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Metadata Record, jež je definováno v souboru `../metadata-record/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../repository/schema.xsd |
Stejný namespace jako hlavní dokument | ../application-profile/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource-to-agent-relationship/schema.xsd |
Stejný namespace jako hlavní dokument | ../language-system/schema.xsd |

#### Kořenové entity XSD schématu

- element `metadata_record`
- komplexní typ `metadata_record`

#### Kořenový element `<metadata_record>`

Typ elementu
Obsah
  Obsahem elementu je typ `metadata_record`.

#### Kořenový komplexní typ `metadata_record`

Význam
  Metadata Record (Description of the metadata record of the dataset. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<date_updated>` [0..*]
- element `<date_created>` [0..1]
- element `<original_repository>` [0..*]
- element `<conforms_to_standard>` [0..*]
- element `<qualified_relation>` [1..*]
- element `<language>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<date_updated>`

Význam
  vlastnost date updated (Date on which the resource was changed.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:date`.

#### Element `<date_created>`

Význam
  vlastnost date created (The date on which the metadata record was created.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:date`.

#### Element `<original_repository>`

Význam
  vlastnost has original repository (Link to the repository in which the metadata were originally stored and curated.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `repository`.
Význam
  Repository (A catalogue or repository that hosts the Datasets or Data Services being described.)

#### Element `<conforms_to_standard>`

Význam
  vlastnost conforms to standard (An established standard to which the metadata record conforms.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `application_profile`.
Význam
  Application profile (A standard or other specification to which a metadata record conforms.)

#### Element `<qualified_relation>`

Význam
  vlastnost qualified relation (Link to a description of a relationship between metadata record and agent with the specification of the role of agent in this relationship.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_to_agent_relationship`.
Význam
  Resource to agent relationship (An association class for attaching additional information to a relationship between Resource and Agent.)

#### Element `<language>`

Význam
  vlastnost language (A language used in the textual metadata describing titles, descriptions of the metadata record.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `language_system`.
Význam
  Language system (A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.)

## Specifikace struktury pro Repository

Data structure for Repository. A curated collection of metadata about resources.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Repository, jež je definováno v souboru `../repository/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `repository`
- komplexní typ `repository`

#### Kořenový element `<repository>`

Typ elementu
Obsah
  Obsahem elementu je typ `repository`.

#### Kořenový komplexní typ `repository`

Význam
  Repository (A catalogue or repository that hosts the Datasets or Data Services being described.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Human readable name of the repository.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Dataset

Data structure for Dataset. A collection of data, published or curated by a single source, and available for access or download in one or more representations.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Dataset, jež je definováno v souboru `../dataset/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../description/schema.xsd |
Stejný namespace jako hlavní dokument | ../alternate-title/schema.xsd |
Stejný namespace jako hlavní dokument | ../metadata-record/schema.xsd |
Stejný namespace jako hlavní dokument | ../identifier/schema.xsd |
Stejný namespace jako hlavní dokument | ../location/schema.xsd |
Stejný namespace jako hlavní dokument | ../provenance-statement/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource-to-agent-relationship/schema.xsd |
Stejný namespace jako hlavní dokument | ../time_reference/schema.xsd |
Stejný namespace jako hlavní dokument | ../subject/schema.xsd |
Stejný namespace jako hlavní dokument | ../validation-result/schema.xsd |
Stejný namespace jako hlavní dokument | ../distribution/schema.xsd |
Stejný namespace jako hlavní dokument | ../funding-reference/schema.xsd |
Stejný namespace jako hlavní dokument | ../terms-of-use/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource-type/schema.xsd |
Stejný namespace jako hlavní dokument | ../language-system/schema.xsd |

#### Kořenové entity XSD schématu

- element `dataset`
- komplexní typ `dataset`

#### Kořenový element `<dataset>`

Typ elementu
Obsah
  Obsahem elementu je typ `dataset`.

#### Kořenový komplexní typ `dataset`

Význam
  Dataset (A collection of data, published or curated by a single source, and available for access or download in one or more representations.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<publication_year>` [1..1]
- element `<version>` [0..1]
- element `<title>` [1..1]
- element `<has_description>` [0..*]
- element `<alternate_title>` [0..*]
- element `<is_described_by>` [1..*]
- element `<identifier>` [1..*]
- element `<location>` [0..*]
- element `<provenance>` [0..*]
- element `<qualified_relation>` [2..*]
- element `<time_reference>` [1..*]
- element `<subject>` [1..*]
- element `<validation_result>` [0..*]
- element `<distribution>` [0..*]
- element `<funding_reference>` [0..*]
- element `<terms_of_use>` [1..1]
- element `<related_resource>` [0..*]
- element `<resource_type>` [0..1]
- element `<other_language>` [0..*]
- element `<primary_language>` [0..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<publication_year>`

Význam
  vlastnost publication year (The year when the item was or will be made publicly available.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:gYear`.

#### Element `<version>`

Význam
  vlastnost version (The version indicator (name or identifier) of a resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<title>`

Význam
  vlastnost title (A name given to the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<has_description>`

Význam
  vlastnost has description (Relation to the description of a dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `description`.
Význam
  Description (All additional information that does not fit in any of the other categories. May be used for technical information or detailed information associated with a scientific instrument.)

#### Element `<alternate_title>`

Význam
  vlastnost has alternate title
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `alternate_title`.
Význam
  Alternate title (Alternate title of the resource.)

#### Element `<is_described_by>`

Význam
  vlastnost is described by (Inverse relation between dataset and metadata record.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `metadata_record`.
Význam
  Metadata Record (Description of the metadata record of the dataset. )

#### Element `<identifier>`

Význam
  vlastnost has identifier (has identifier)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.
Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)

#### Element `<location>`

Význam
  vlastnost has location (The geographical area covered by the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `location`.
Význam
  Location (Spatial region, named place or geometry representation of a place related to the dataset. )

#### Element `<provenance>`

Význam
  vlastnost has provenance (A statement about the lineage of a Dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `provenance_statement`.
Význam
  Provenance Statement (Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.)

#### Element `<qualified_relation>`

Význam
  vlastnost qualified relation (Link to a description of a relationship between dataset and an agent with the specification of the role of agent in this relationship.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  2..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_to_agent_relationship`.
Význam
  Resource to agent relationship (An association class for attaching additional information to a relationship between Resource and Agent.)

#### Element `<time_reference>`

Význam
  vlastnost has time reference (Reference to events related to the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_reference`.
Význam
  Time interval (A temporal entity with an extent or duration)

#### Element `<subject>`

Význam
  vlastnost has subject (Dataset described using a subject.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `subject`.
Význam
  Subject (Subject, keyword, classification code, or key phrase describing the resource.)

#### Element `<validation_result>`

Význam
  vlastnost has validation result (Reference to the report about the dataset validation.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `validation_result`.
Význam
  Validation result (Class describing the result of validation testing. It may include validation of metadata, data and/or web services accessing the data.)

#### Element `<distribution>`

Význam
  vlastnost has distribution (An available Distribution for the Dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `distribution`.
Význam
  Distribution - data service (Physical embodiment of the dataset distribution as a particular data service. )

#### Element `<funding_reference>`

Význam
  vlastnost has funding reference (Has reference for funding of a dataset acquisition.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `funding_reference`.
Význam
  Funding reference (Information about financial support (funding) for the resource being registered.)

#### Element `<terms_of_use>`

Význam
  vlastnost has terms of use (Terms under which the dataset may be accessed.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `terms_of_use`.
Význam
  Terms of use (Terms of use defines overall conditions and rights regarding access and usage of dataset. )

#### Element `<related_resource>`

Význam
  vlastnost has related resource (Reference to the resource in any way related to the described dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource`.
Význam
  Resource (Resource represents any resource, physical or digital, that is related to the described dataset. )

#### Element `<resource_type>`

Význam
  vlastnost has resource type (A resource type of the Dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_type`.
Význam
  Resource type (Type of the resource.)

#### Element `<other_language>`

Význam
  vlastnost has other language (Any other languages of the Dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `language_system`.
Význam
  Language system (A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.)

#### Element `<primary_language>`

Význam
  vlastnost has other language (Any other languages of the Dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `language_system`.
Význam
  Language system (A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.)

## Specifikace struktury pro Identifier

Data structure for Identifier. This is based on the UN/CEFACT Identifier class.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Identifier, jež je definováno v souboru `../identifier/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../identifier-scheme/schema.xsd |

#### Kořenové entity XSD schématu

- element `identifier`
- komplexní typ `identifier`

#### Kořenový element `<identifier>`

Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.

#### Kořenový komplexní typ `identifier`

Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<value>` [1..1]
- element `<scheme>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<value>`

Význam
  vlastnost value (Value of the identifer within the given identifier scheme.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<scheme>`

Význam
  vlastnost in scheme (Relation between the identifier and scheme in which it is defined and unique.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier_scheme`.
Význam
  Identifier scheme (Scheme in which is the identifier value unique, usually representing some authority. Identifier scheme shall always be represented as IRI identifier.)

## Specifikace struktury pro Alternate title

Data structure for Alternate title. Alternate title f the resource

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Alternate title, jež je definováno v souboru `../alternate-title/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../alternate-title-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `alternate_title`
- komplexní typ `alternate_title`

#### Kořenový element `<alternate_title>`

Typ elementu
Obsah
  Obsahem elementu je typ `alternate_title`.

#### Kořenový komplexní typ `alternate_title`

Význam
  Alternate title (Alternate title of the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<title>` [1..*]
- element `<alternate_title_type>` [0..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<title>`

Význam
  vlastnost title (A human-readable name for the subject.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<alternate_title_type>`

Význam
  vlastnost has alternate title type (Type of the alternate name relation.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `alternate_title_type`.
Význam
  Alternate title type (Type of alternate title.)

## Specifikace struktury pro Geometry

Data structure for Geometry. The Geometry class provides the means to identify a location as a point, line, polygon, etc. expressed using coordinates in some coordinate reference system.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Geometry, jež je definováno v souboru `../geometry/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `geometry`
- komplexní typ `geometry`

#### Kořenový element `<geometry>`

Typ elementu
Obsah
  Obsahem elementu je typ `geometry`.

#### Kořenový komplexní typ `geometry`

Význam
  Geometry (The Geometry class provides the means to identify a location as a point, line, polygon, etc. expressed using coordinates in some coordinate reference system.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<label>` [0..*]
- element `<geography_markup_language_literal>` [0..*]
- element `<well_known_text_literal>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of geometry object.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<geography_markup_language_literal>`

Význam
  vlastnost geography markup language literal (Representation of geometry object as GML Literal.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anySimpleType`.

#### Element `<well_known_text_literal>`

Význam
  vlastnost well known text literal (Representation of geometry object as WKT Literal.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anySimpleType`.

## Specifikace struktury pro Documentation

Data structure for Documentation. A textual resource intended for human consumption that contains information about the data service.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Documentation, jež je definováno v souboru `../documentation/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `documentation`
- komplexní typ `documentation`

#### Kořenový element `<documentation>`

Typ elementu
Obsah
  Obsahem elementu je typ `documentation`.

#### Kořenový komplexní typ `documentation`

Význam
  Documentation (A textual resource intended for human consumption that contains information about the data service.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Documentation label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Data service

Data structure for Data service. A collection of operations that provides access to one or more datasets or data processing functions.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Data service, jež je definováno v souboru `../data-service/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../resource/schema.xsd |

#### Kořenové entity XSD schématu

- element `data_service`
- komplexní typ `data_service`

#### Kořenový element `<data_service>`

Typ elementu
Obsah
  Obsahem elementu je typ `data_service`.

#### Kořenový komplexní typ `data_service`

Význam
  Data service (A collection of operations that provides access to one or more datasets or data processing functions.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]
- element `<endpoint_url>` [1..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Data service label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<endpoint_url>`

Význam
  vlastnost endpoint URL (The root location or primary endpoint of the service (an IRI).)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource`.
Význam
  Resource (Resource represents any resource, physical or digital, that is related to the described dataset. )

## Specifikace struktury pro Checksum

Data structure for Checksum. A value that allows the contents of a file to be authenticated.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Checksum, jež je definováno v souboru `../checksum/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Nic není importováno.

#### Kořenové entity XSD schématu

- element `checksum`
- komplexní typ `checksum`

#### Kořenový element `<checksum>`

Typ elementu
Obsah
  Obsahem elementu je typ `checksum`.

#### Kořenový komplexní typ `checksum`

Význam
  Checksum (A value that allows the contents of a file to be authenticated.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<checksum_value>` [1..1]
- element `<algorithm>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<checksum_value>`

Význam
  vlastnost checksum value (A lower case hexadecimal encoded digest value produced using a specific algorithm. )
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:hexBinary`.

#### Element `<algorithm>`

Význam
  vlastnost uses algorithm (The algorithm used to produce the subject Checksum.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

## Specifikace struktury pro Organization

Data structure for Organization. Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Organization, jež je definováno v souboru `../organization/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../identifier/schema.xsd |
Stejný namespace jako hlavní dokument | ../contact-details/schema.xsd |
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `organization`
- komplexní typ `organization`

#### Kořenový element `<organization>`

Typ elementu
Obsah
  Obsahem elementu je typ `organization`.

#### Kořenový komplexní typ `organization`

Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<name>` [1..1]
- element `<identifier>` [0..*]
- element `<contact_point>` [0..*]
- element `<alternate_name>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<name>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost name (Name of the agent.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<identifier>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost has identifier (has identifier)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.
Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)

#### Element `<contact_point>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost has contact point (Relevant contact information for the catalogued resource. )
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `contact_details`.
Význam
  Contact details (Details to contact the agent in a relationship to the resource.)

#### Element `<alternate_name>`

Význam
  vlastnost alternate name (To specify the organizational name associated with the object)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro License Document

Data structure for License Document. A legal document giving official permission to do something with a resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro License Document, jež je definováno v souboru `../license-document/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `license_document`
- komplexní typ `license_document`

#### Kořenový element `<license_document>`

Typ elementu
Obsah
  Obsahem elementu je typ `license_document`.

#### Kořenový komplexní typ `license_document`

Význam
  License Document (A legal document giving official permission to do something with a resource.)
Obsah - elementy v tomto pořadí

- element `<label>` [0..*]

#### Element `<label>`

Význam
  vlastnost label (Label of the license document.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Date type

Data structure for Date type. Type of a date in relation to the resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Date type, jež je definováno v souboru `../date-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `date_type`
- komplexní typ `date_type`

#### Kořenový element `<date_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `date_type`.

#### Kořenový komplexní typ `date_type`

Význam
  Date type (Type of a date in relation to the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Date type label.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Resource relation type

Data structure for Resource relation type. Type of the relation between the dataset and given resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Resource relation type, jež je definováno v souboru `../resource-relation-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `resource_relation_type`
- komplexní typ `resource_relation_type`

#### Kořenový element `<resource_relation_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `resource_relation_type`.

#### Kořenový komplexní typ `resource_relation_type`

Význam
  Resource relation type (Type of the relation between the dataset and given resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the relation type.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Resource type

Data structure for Resource type. Type of the resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Resource type, jež je definováno v souboru `../resource-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `resource_type`
- komplexní typ `resource_type`

#### Kořenový element `<resource_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `resource_type`.

#### Kořenový komplexní typ `resource_type`

Význam
  Resource type (Type of the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the resource type.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Location relation type

Data structure for Location relation type. Relation of the dataset to the resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Location relation type, jež je definováno v souboru `../location-relation-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `relation_type`
- komplexní typ `relation_type`

#### Kořenový element `<relation_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `relation_type`.

#### Kořenový komplexní typ `relation_type`

Význam
  Location relation type (Relation of the dataset to the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of location relation type.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Format

Data structure for Format. Format of downloadable file.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Format, jež je definováno v souboru `../format/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `format`
- komplexní typ `format`

#### Kořenový element `<format>`

Typ elementu
Obsah
  Obsahem elementu je typ `format`.

#### Kořenový komplexní typ `format`

Význam
  Format (Format of downloadable file.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of format value.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Alternate title type

Data structure for Alternate title type. Type of alternate title.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Alternate title type, jež je definováno v souboru `../alternate-title-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `alternate_title_type`
- komplexní typ `alternate_title_type`

#### Kořenový element `<alternate_title_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `alternate_title_type`.

#### Kořenový komplexní typ `alternate_title_type`

Význam
  Alternate title type (Type of alternate title.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Alternate title type label.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Access rights

Data structure for Access rights. Access rights to the resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Access rights, jež je definováno v souboru `../access-rights/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `access_rights`
- komplexní typ `access_rights`

#### Kořenový element `<access_rights>`

Typ elementu
Obsah
  Obsahem elementu je typ `access_rights`.

#### Kořenový komplexní typ `access_rights`

Význam
  Access rights (A statement about the access rights to the dataset.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the access rights vocabulary value.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Language system

Data structure for Language system. A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Language system, jež je definováno v souboru `../language-system/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `language_system`
- komplexní typ `language_system`

#### Kořenový element `<language_system>`

Typ elementu
Obsah
  Obsahem elementu je typ `language_system`.

#### Kořenový komplexní typ `language_system`

Význam
  Language system (A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Language label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Identifier scheme

Data structure for Identifier scheme. Scheme in which is the identifier value unique, usually representing some authority. Identifier scheme shall always be represented as IRI identifier.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Identifier scheme, jež je definováno v souboru `../identifier-scheme/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `identifier_scheme`
- komplexní typ `identifier_scheme`

#### Kořenový element `<identifier_scheme>`

Typ elementu
Obsah
  Obsahem elementu je typ `identifier_scheme`.

#### Kořenový komplexní typ `identifier_scheme`

Význam
  Identifier scheme (Scheme in which is the identifier value unique, usually representing some authority. Identifier scheme shall always be represented as IRI identifier.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Identifier scheme label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Time instant

Data structure for Time instant. A temporal entity with zero extent or duration.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Time instant, jež je definováno v souboru `../time-instant/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../date-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `time_instant`
- komplexní typ `time_instant`

#### Kořenový element `<time_instant>`

Typ elementu
Obsah
  Obsahem elementu je typ `time_instant`.

#### Kořenový komplexní typ `time_instant`

Význam
  Time instant (A temporal entity with zero extent or duration.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<date_information>` [0..1]
- element `<date_type>` [1..1]
- výběr jednoho prvku [1..1]
  - element `<date_time>` [1..1]
  - element `<date>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<date_information>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost date information (Additional information to the date in text form.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<date_type>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost has date type (Reference to the codelist of date types.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `date_type`.
Význam
  Date type (Type of a date in relation to the resource.)

#### Element `<date_time>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:dateTime`.

#### Element `<date>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:date`.

## Specifikace struktury pro Time interval

Data structure for Time interval. A temporal entity with an extent or duration

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Time interval, jež je definováno v souboru `../time-interval/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../date-type/schema.xsd |
Stejný namespace jako hlavní dokument | ../time-instant/schema.xsd |

#### Kořenové entity XSD schématu

- element `time_interval`
- komplexní typ `time_interval`

#### Kořenový element `<time_interval>`

Typ elementu
Obsah
  Obsahem elementu je typ `time_interval`.

#### Kořenový komplexní typ `time_interval`

Význam
  Time interval (A temporal entity with an extent or duration)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<date_information>` [0..1]
- element `<has_date_type>` [1..1]
- element `<has_end>` [1..1]
- element `<has_beginning>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<date_information>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost date information (Additional information to the date in text form.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<has_date_type>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost has date type (Reference to the codelist of date types.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `date_type`.
Význam
  Date type (Type of a date in relation to the resource.)

#### Element `<has_end>`

Význam
  vlastnost has end (Time instant representing the end of a temporal interval.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_instant`.
Význam
  Time instant (A temporal entity with zero extent or duration.)

#### Element `<has_beginning>`

Význam
  vlastnost has beginning (Time instant representing the beginning of a temporal interval.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_instant`.
Význam
  Time instant (A temporal entity with zero extent or duration.)

## Specifikace struktury pro Checksum algorithm

Data structure for Checksum algorithm. Algorithm used for Checksums.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Checksum algorithm, jež je definováno v souboru `../checksum-algorithm/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Nic není importováno.

#### Kořenové entity XSD schématu

- element `checksum_algorithm`
- komplexní typ `checksum_algorithm`

#### Kořenový element `<checksum_algorithm>`

Typ elementu
Obsah
  Obsahem elementu je typ `checksum_algorithm`.

#### Kořenový komplexní typ `checksum_algorithm`

Význam
  Checksum algorithm (Algorithm used for Checksums.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

## Specifikace struktury pro Description type

Data structure for Description type. The type of the description.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Description type, jež je definováno v souboru `../description-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Nic není importováno.

#### Kořenové entity XSD schématu

- element `description_type`
- komplexní typ `description_type`

#### Kořenový element `<description_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `description_type`.

#### Kořenový komplexní typ `description_type`

Význam
  Description type (The type of the description.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the description type.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

## Specifikace struktury pro Description

Data structure for Description. All additional information that does not fit in any of the other categories. May be used for technical information or detailed information associated with a scientific instrument.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Description, jež je definováno v souboru `../description/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../description-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `description`
- komplexní typ `description`

#### Kořenový element `<description>`

Typ elementu
Obsah
  Obsahem elementu je typ `description`.

#### Kořenový komplexní typ `description`

Význam
  Description (All additional information that does not fit in any of the other categories. May be used for technical information or detailed information associated with a scientific instrument.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<description_text>` [1..1]
- element `<has_description_type>` [0..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<description_text>`

Význam
  vlastnost description text (Text describing the resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<has_description_type>`

Význam
  vlastnost has description type (Relation to the type of the description.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `description_type`.
Význam
  Description type (The type of the description.)

## Used prefixes

Prefix | Namespace IRI
--- | ---
`dcterms` | `http://purl.org/dc/terms/`
`rdfs` | `http://www.w3.org/2000/01/rdf-schema#`
`rdf` | `http://www.w3.org/1999/02/22-rdf-syntax-ns#`
`locn` | `http://www.w3.org/ns/locn#`
`xsd` | `http://www.w3.org/2001/XMLSchema#`
`foaf` | `http://xmlns.com/foaf/0.1/`
`dcat` | `http://www.w3.org/ns/dcat#`
`skos` | `http://www.w3.org/2004/02/skos/core#`
`spdx` | `http://spdx.org/rdf/terms#`
`vcard` | `http://www.w3.org/2006/vcard/ns#`
`adms` | `http://www.w3.org/ns/adms#`
`prov` | `http://www.w3.org/ns/prov#`
`time` | `http://www.w3.org/2006/time#`

## Attachments

This specification includes the following attachments.

Attachment | Link
--- | ---
Application profile | ./dsv.ttl
XML schéma | ../agent/schema.xsd
XML schéma | ../distribution/schema.xsd
XML schéma | ../contact-details/schema.xsd
XML schéma | ../resource/schema.xsd
XML schéma | ../location/schema.xsd
XML schéma | ../time_reference/schema.xsd
XML schéma | ../funding-reference/schema.xsd
XML schéma | ../terms-of-use/schema.xsd
XML schéma | ../resource-to-agent-relationship/schema.xsd
XML schéma | ../resource-agent-role-type/schema.xsd
XML schéma | ../application-profile/schema.xsd
XML schéma | ../media-type/schema.xsd
XML schéma | ../file/schema.xsd
XML schéma | ../validation-result/schema.xsd
XML schéma | ../subject-scheme/schema.xsd
XML schéma | ../address/schema.xsd
XML schéma | ../provenance-statement/schema.xsd
XML schéma | ../media-type/schema.xsd
XML schéma | ../subject/schema.xsd
XML schéma | ../metadata-record/schema.xsd
XML schéma | ../repository/schema.xsd
XML schéma | ../dataset/schema.xsd
XML schéma | ../identifier/schema.xsd
XML schéma | ../alternate-title/schema.xsd
XML schéma | ../geometry/schema.xsd
XML schéma | ../documentation/schema.xsd
XML schéma | ../data-service/schema.xsd
XML schéma | ../checksum/schema.xsd
XML schéma | ../organization/schema.xsd
XML schéma | ../license-document/schema.xsd
XML schéma | ../date-type/schema.xsd
XML schéma | ../resource-relation-type/schema.xsd
XML schéma | ../resource-type/schema.xsd
XML schéma | ../location-relation-type/schema.xsd
XML schéma | ../format/schema.xsd
XML schéma | ../alternate-title-type/schema.xsd
XML schéma | ../access-rights/schema.xsd
XML schéma | ../language-system/schema.xsd
XML schéma | ../identifier-scheme/schema.xsd
XML schéma | ../time-instant/schema.xsd
XML schéma | ../time-interval/schema.xsd
XML schéma | ../checksum-algorithm/schema.xsd
XML schéma | ../description-type/schema.xsd
XML schéma | ../description/schema.xsd
Dokumentace | #